<?php
/**
 * Custom header implementation
 *
 * @link https://codex.wordpress.org/Custom_Headers
 *
 * @package Construction Hub
 * @subpackage construction_hub
 */

function construction_hub_custom_header_setup() {
    register_default_headers( array(
        'default-image' => array(
            'url'           => get_template_directory_uri() . '/assets/images/header_img.png',
            'thumbnail_url' => get_template_directory_uri() . '/assets/images/header_img.png',
            'description'   => __( 'Default Header Image', 'construction-hub' ),
        ),
    ) );
}
add_action( 'after_setup_theme', 'construction_hub_custom_header_setup' );

/**
 * Styles the header image based on Customizer settings.
 */
function construction_hub_header_style() {
    $construction_hub_header_image = get_header_image() ? get_header_image() : get_template_directory_uri() . '/assets/images/header_img.png';

    $construction_hub_height     = get_theme_mod( 'construction_hub_header_image_height', 350 );
    $construction_hub_position   = get_theme_mod( 'construction_hub_header_background_position', 'center' );
    $construction_hub_attachment = get_theme_mod( 'construction_hub_header_background_attachment', 1 ) ? 'fixed' : 'scroll';

    $construction_hub_custom_css = "
        .header-img, .headerimg, .single-page-img, .external-div .box-image-page img, .external-div {
            background-image: url('" . esc_url( $construction_hub_header_image ) . "');
            background-size: cover;
            height: " . esc_attr( $construction_hub_height ) . "px;
            background-position: " . esc_attr( $construction_hub_position ) . ";
            background-attachment: " . esc_attr( $construction_hub_attachment ) . ";
        }

        @media (max-width: 1000px) {
            .header-img, .single-page-img, .external-div .box-image-page img,.external-div,.featured-image{
                height: 250px !important;
            }
            .box-text h2{
                font-size: 27px;
            }
        }
    ";

    wp_add_inline_style( 'construction-hub-style', $construction_hub_custom_css );
}
add_action( 'wp_enqueue_scripts', 'construction_hub_header_style' );

/**
 * Enqueue the main theme stylesheet.
 */
function construction_hub_enqueue_styles() {
    wp_enqueue_style( 'construction-hub-style', get_stylesheet_uri() );
}
add_action( 'wp_enqueue_scripts', 'construction_hub_enqueue_styles' );