
.disable__comment__alert {
    border: 0px;
    background: #fff;
    display: flex;
    align-items: center;
    padding: 10px 20px;
    margin-top: 50px;
    margin-right: 20px;
  }
  @media (max-width: 767.98px) {
    .disable__comment__alert {
      display: block;
    }
    .disable__comment__alert .button__group {
      margin-top: 20px;
    }
  }
  .disable__comment__alert .alert__content {
    display: flex;
    align-items: center;
    padding-right: 20px;
    flex-wrap: wrap;
    flex: 1;
  }
  @media (max-width: 767.98px) {
    .disable__comment__alert .alert__content {
      padding-right: 0;
    }
  }
  @media (max-width: 575.98px) {
    .disable__comment__alert .alert__content {
      display: block;
    }
  }
  .disable__comment__alert .alert__content img, .disable__comment__alert > img {
    margin-right: 15px;
    height: 30px;
  }
  @media (max-width: 575.98px) {
    .disable__comment__alert .alert__content img {
      margin-bottom: 10px;
    }
  }
  .disable__comment__alert .alert__content p {
    font-size: 15px;
    font-weight: 500;
    color: #22282d;
    font-family: "DM Sans", sans-serif;
  }
  .disable__comment__alert .button__group {
    text-align: right;
  }
  @media (max-width: 767.98px) {
    .disable__comment__alert .button__group {
      text-align: left;
    }
  }
  .disable__comment__alert .button__group .button {
    margin-right: 0;
    margin-top: 5px;
    margin-bottom: 5px;
    color: #ffffff;
    background: #05cb6b;
    border: 0;
    transition: all 0.3s ease 0s;
  }
  .disable__comment__alert .button__group .button:last-child {
    background-color: #fff;
    color: #808da1;
  }

  .disable__comment__alert .button__group .button:hover {
    background: #05cb6b;
    color: #ffffff;
  }
  .disable__comment__alert .button__group .button:not(:last-child) {
    margin-right: 0;
  }
  .disable__comment__alert .button__group .button:not(:first-child) {
    margin-left: 15px;
  }
  @media (max-width: 767.98px) {
    .disable__comment__alert .button__group .button {
      margin-right: 10px;
    }
    .disable__comment__alert .button__group .button:not(:last-child) {
      margin-right: 10px;
    }
    .disable__comment__alert .button__group .button:not(:first-child) {
      margin-left: 0;
    }
  }

  .disable__comment__alert .alert__content .wpinsights-data {
    font-size: 10px;
  }