<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-12-09 02:48:04+0000','plural-forms'=>'nplurals=1; plural=0;','project-id-version'=>'Plugins - Contact Form 7 - Stable (latest release)','language'=>'zh_CN','messages'=>['Brevo is active on this site.'=>'Brevo 在此站点上已启用。','Brevo'=>'Brevo','The next major release of Contact Form 7 will discontinue support for outdated PHP versions. If you don\'t upgrade PHP, you will not be able to upgrade the plugin.'=>'Contact Form 7 的下一个大版本将停止对过时的 PHP 版本的支持。如果您不及时更新 PHP，您将无法升级此插件。','Contact form not found.'=>'未找到这个表单','Error:'=>'报错：','block keywordform'=>'表单','block descriptionInsert a contact form you have created with Contact Form 7.'=>'插入您用Contact Form 7创建的留言表单。','block titleContact Form 7'=>'Contact Form 7','&#8212;Please choose an option&#8212;'=>'&#8212;请选择&#8212;','Akismet is active on this site.'=>'该网站启用了Akismet。','CAPTCHAs are designed to distinguish spambots from humans, and are therefore helpless against human spammers. In contrast to CAPTCHAs, Akismet checks form submissions against the global database of spam; this means Akismet is a comprehensive solution against spam. This is why we consider Akismet to be the centerpiece of the spam prevention strategy.'=>'CAPTCHA是用于区分垃圾邮件机器人和人类用户的，因此对人类垃圾邮件发送者无能为力。与CAPTCHA不同的是，Akismet会将表单提交内容与全球垃圾邮件数据库进行比对，这意味着Akismet是一种全面防止垃圾邮件的解决方案。这就是为什么我们认为Akismet是防止垃圾邮件策略的核心的原因。','Learn how your data is processed.'=>'了解您的数据是如何进行处理的。','This form uses Akismet to reduce spam.'=>'此表单使用Akismet来减少垃圾邮件。','Contact form'=>'留言表单','Uploadable file size exceeds PHP’s maximum acceptable size.'=>'上传的文件大小超过了PHP所能接受的最大文件尺寸。','Colons are used in form-tag names.'=>'表单标签名称中使用了冒号。','This field has a too large number.'=>'此字段的数字太大。','This field has a too small number.'=>'该字段的数字太小。','This field has a too late date.'=>'此字段的日期太晚。','This field has a too early date.'=>'这个字段的日期太早了。','Please enter a date in YYYY-MM-DD format.'=>'请以 YYYY-MM-DD 格式输入日期。','The request payload format is not supported.'=>'不支持请求负载格式。','Hook %1$s is <strong>deprecated</strong> since Contact Form 7 version %2$s with no alternative available.'=>'自 Contact Form 7 版本 %2$s 以来，挂钩 %1$s 已被<strong>弃用</strong>，没有其他可用的替代方法。','This field has a too short input.'=>'此字段的输入太短。','This field has a too long input.'=>'此字段的输入太长。','Function %1$s is <strong>deprecated</strong> since Contact Form 7 version %2$s! Use %3$s instead.'=>'自从 Contact Form 7 版本 %2$s 起，功能 %1$s 已被<strong>弃用</strong>！请改用 %3$s。','Spam protection'=>'垃圾邮件防护','Function %1$s was called incorrectly. %2$s %3$s'=>'函数 %1$s 调用不正确。 %2$s %3$s','Hello,

This is a confirmation email sent from %1$s.

We have received your submission to our web form, according to which you have allowed us to add you to our contact list. But, the process has not yet been completed. To complete it, please click the following link.

%2$s

If it was not your intention, or if you have no idea why you received this message, please do not click on the link, and ignore this message. We will never collect or use your personal data without your clear consent.

Sincerely,
%1$s'=>'您好，

这是一封来自 %1$s 的确认电子邮件。

我们已收到您提交给我们的网络表单的内容，您已允许我们将您添加到我们的联系人列表中。但是，该过程尚未完成。要完成它，请点击以下链接。

%2$s

如果这不是您的意图，或者如果您不知道为什么收到此消息，请不要点击链接，并忽略这条信息。未经您的明确同意，我们绝不会收集或使用您的个人数据。

此致，
%1$s','Opt-in confirmation from %s'=>'来自 %s 的选择确认','You can set up the Constant Contact integration here. For details, see %s.'=>'您可以在此处设置恒定联系集成。有关详细信息，请参阅 %s。','Complete payment'=>'完成支付','Proceed to checkout'=>'进行结算','Payment is required. Please pay by credit card.'=>'需要付款。请用信用卡支付。','Payments'=>'付款','Publishable Key'=>'可发布密钥','Stripe is not available on this site. It requires an HTTPS-enabled site.'=>'本网站不提供 Stripe。它需要启用 HTTPS 的站点。','Stripe is active on this site.'=>'Stripe 在这个网站上很活跃。','Stripe integration'=>'条带集成','Stripe is a simple and powerful way to accept payments online. Stripe has no setup fees, no monthly fees, and no hidden costs. Millions of businesses rely on Stripe’s software tools to accept payments securely and expand globally.'=>'Stripe 是一种简单而强大的在线接受付款方式。 Stripe 没有安装费、月费和隐藏费用。数以百万计的企业依靠 Stripe 的软件工具来安全地接受付款并在全球范围内扩张。有关详细信息，请参阅 %s。','personal name%1$s %2$s'=>'%1$s %2$s','Unique identifier for the contact form.'=>'联系表单的唯一标识符。','Dots are used in form-tag names.'=>'点用于表单标签名称。','Show welcome panel'=>'显示欢迎面板','Welcome panel'=>'欢迎面板','Stripe'=>'条纹','https://contactform7.com/stripe-integration/'=>'https://contactform7.com/stripe-integration/','With help from cloud-based machine learning, anti-spam services will protect your forms (%1$s). Even payment services are natively supported (%2$s).'=>'在基于云的机器学习的帮助下，反垃圾邮件服务将保护您的表单 (%1$s)。甚至原生支持支付服务 (%2$s)。','Your contact forms will become more powerful and versatile by integrating them with external APIs. With CRM and email marketing services, you can build your own contact lists (%1$s).'=>'通过与外部 API 集成，您的联系表单将变得更加强大和通用。借助 CRM 和电子邮件营销服务，您可以建立自己的联系人列表（%1$s）。','You have strong allies to back you up.'=>'你有强大的盟友来支持你。','Integration with external APIs'=>'与外部 API 集成','https://contactform7.com/integration-with-external-apis/'=>'https://contactform7.com/integration-with-external-apis/','You can expand the possibilities of your contact forms by integrating them with external services. For details, see %s.'=>'您可以通过将联系表与外部服务集成来扩展联系表的可能性。有关详细信息，请参阅 %s。','Integration with External API'=>'集成外部API','Manage your email templates'=>'管理您的电子邮件模板','You have no active email template yet.'=>'您还没有有效的电子邮件模板。','&mdash; Select &mdash;'=>'&mdash;选择&mdash;','Select an email template:'=>'选择一个电子邮件模板。：','Send a welcome email to new contacts'=>'向新联系人发送欢迎邮件','Welcome email'=>'欢迎邮件','(opens in a new tab)'=>'（在新标签页中打开）','Manage your contact lists'=>'管理您的联系人列表','You have no contact list yet.'=>'您还没有联系人列表。','Select lists to which contacts are added:'=>'选择要添加联系人的列表。：','Add form submitters to your contact lists'=>'将表单提交者添加到您的联系人列表中','Contact lists'=>'联系人列表','You can set up the Brevo integration here. For details, see %s.'=>'您可以在这里设置 Brevo 集成。详情请看 %s。','Save changes'=>'保存更改','API keysRemove key'=>'移除密钥','API key'=>'API密钥','Setup integration'=>'配置集成','https://contactform7.com/sendinblue-integration/'=>'https://contactform7.com/sendinblue-integration/','Store and organize your contacts while protecting user privacy on Brevo, the leading CRM & email marketing platform in Europe. Brevo offers unlimited contacts and advanced marketing features.'=>'在欧洲领先的CRM和电子邮件营销平台Sendinblue上存储和组织您的联系人，同时保护用户隐私。Sendinblue提供无限的联系人和高级营销功能。','You have not been authenticated. Make sure the provided API key is correct.'=>'您尚未通过身份验证。请确保您所提供的API密钥正确。','Failed to attach a file. The total file size exceeds the limit of 25 megabytes.'=>'无法附加文件。总文件大小超过 25 兆字节的限制。','Failed to attach a file. %s is not a readable file.'=>'无法附加文件。 %s 不是可读文件。','Failed to attach a file. %s is not in the allowed directory.'=>'无法附加文件。 %s 不在允许的目录中。','Submit'=>'提交','(optional)'=>'(可选)','disallowed list'=>'不允许列表','Disallowed words (%s) are used.'=>'使用了不允许的字词 (%s)。','Disallowed words are used.'=>'使用不允许的词。','(This message was added in Contact Form 7 version %s.)'=>'(此消息是在 Contact Form 7 版本%s中添加的。)','The fourth parameter ($mail_tag) must be an instance of the WPCF7_MailTag class.'=>'第四个参数($mail_tag)必须是WPCF7_MailTag类的实例。','g:i a'=>'H:i','%1$s at %2$s'=>'%1$s %2$s','docs'=>'文档','%1$s and %2$s'=>'%1$s 和 %2$s','Additional settings'=>'其他设置','Error'=>'错误','The total size of attachment files is too large.'=>'附件文件总和太大。','Unavailable HTML elements are used in the form template.'=>'表单模板中使用了不可用的HTML元素。','reCAPTCHA is active on this site.'=>'reCAPTCHA在此站点上已启用。','reCAPTCHA response token is empty.'=>'reCAPTCHA响应令牌为空。','Submitted nonce is invalid.'=>'提交的nonce无效。','User-Agent string is unnaturally short.'=>'User-Agent 字符串太短。','reCAPTCHA score (%1$.2f) is lower than the threshold (%2$.2f).'=>'reCAPTCHA得分(%1$.2f)低于阈值(%2$.2f)。','Akismet returns a spam response.'=>'Akismet返回了一个垃圾内容响应。','API keysReset Keys'=>'重置 Keys','This site is connected to the Constant Contact API.'=>'此站点已连接 Constant Contact API。','Configuration updated.'=>'配置已更新。','Failed to establish connection. Please double-check your configuration.'=>'建立连接失败。请仔细检查您的配置。','Connection established.'=>'已建立连接。','HTTP Response: %1$s %2$s %3$s from %4$s'=>'HTTP响应如下: %1$s %2$s %3$s from %4$s','Save Changes'=>'保存更改','reCAPTCHA protects you against spam and other types of automated abuse. With Contact Form 7&#8217;s reCAPTCHA integration module, you can block abusive form submissions by spam bots.'=>'reCAPTCHA可以保护您免受垃圾邮件和其他类型的自动滥用的侵害。借助Contact Form 7的reCAPTCHA集成模块，您可以阻止垃圾邮件机器人提交有害的表单。','reCAPTCHA (v3)'=>'reCAPTCHA (v3)','API keys for reCAPTCHA v3 are different from those for v2; keys for v2 do not work with the v3 API. You need to register your sites again to get new keys for v3. For details, see %s.'=>'reCAPTCHA v3的API密钥与v2不同；v2的密钥无法与v3 API一起使用。您需要重新注册您的网站以获取v3的新密钥。想了解更多详情，请参见%s。','Connect to the Constant Contact API'=>'连接至 Constant Contact API','API keysRemove Keys'=>'删除密钥','Set this URL as the redirect URI.'=>'将此URL设置为重定向URI。','Redirect URI'=>'重定向 URI','App Secret'=>'应用秘钥','API Key'=>'API密钥','Setup Integration'=>'配置集成','Constant Contact integration'=>'Constant Contact 集成','https://contactform7.com/constant-contact-integration/'=>'https://contactform7.com/constant-contact-integration/','The Constant Contact integration module allows you to send contact data collected through your contact forms to the Constant Contact API. You can create reliable email subscription services in a few easy steps.'=>'Constant Contact集成模块允许您将通过您的联系表单收集的联系数据发送到Constant Contact API。您可以通过几个简单的步骤创建可靠的电子邮件订阅服务。','Constant Contact'=>'Constant Contact','Email marketing'=>'邮件营销','It is not allowed to use files outside the wp-content directory.'=>'不允许使用wp-content目录之外的文件。','Professional services'=>'专业服务','https://contactform7.com/custom-development/'=>'https://contactform7.com/custom-development/','Support forums'=>'支持论坛','https://wordpress.org/support/plugin/contact-form-7/'=>'https://wordpress.org/support/plugin/contact-form-7/','Here are some available options to help solve your problems.'=>'这里有一些可用的选项可帮助您解决部分问题。','Do you need help?'=>'是否需要帮助？','Condition'=>'条件','mail output for acceptance checkboxes%1$s: %2$s'=>'%1$s：%2$s','Not consented'=>'已不同意','Consented'=>'已同意','Sending mail has been aborted.'=>'发送邮件已中止。','You can edit messages used in various situations here. For details, see %s.'=>'您可以编辑在各种情况下使用的消息。有关详细信息，请参见%s。','Editing messages'=>'编辑消息','https://contactform7.com/editing-messages/'=>'https://contactform7.com/editing-messages/','You can edit the mail template here. For details, see %s.'=>'您可以在这里编辑邮件模板。有关详细信息，请参见%s。','You can edit the form template here. For details, see %s.'=>'您可以在这里编辑表单模板。有关详细信息，请参见%s。','Editing form template'=>'编辑表单模板','https://contactform7.com/editing-form-template/'=>'https://contactform7.com/editing-form-template/','This contact form is available only for logged in users.'=>'此联系人表单仅供已登录地用户填写。','Deprecated settings are used.'=>'已被废弃的设置正在被使用。','To use CAPTCHA, you need %s plugin installed.'=>'要使用 CAPTCHA，您需要安装%s插件。','There was an error deleting the contact form.'=>'删除联系表单时出错。','You are not allowed to access the requested contact form.'=>'您不能取数您要的联系表单。','The requested contact form was not found.'=>'没有找到您要的联系表单。','You are not allowed to create a contact form.'=>'您不能创建联系表单。','Cannot create existing contact form.'=>'无法创建现有的联系表单。','You are not allowed to access contact forms.'=>'您无权访问联系表单。','Attachment file does not exist at %path%.'=>'在％path％不存附件文件。','Invalid mailbox syntax is used in the %name% field.'=>'％name％字段中使用无效的邮箱语法。','Unavailable names (%names%) are used for form controls.'=>'不可用的名称（％names％）用于表单控件。','There are invalid mail header fields.'=>'有无效的邮件标头。','HTML tags are used in a message.'=>'HTML 标签在消息中使用。','Sender email address does not belong to the site domain.'=>'发件人电子邮件地址不属于站点域名。','Invalid mailbox syntax is used.'=>'使用无效的邮箱语法。','There is a possible empty field.'=>'有一个可能的空字段。','%s configuration error detected'=>'检测到%s个配置错误','There was an error saving the contact form.'=>'保存联系表单时出错。','Hook %1$s is <strong>deprecated</strong> since Contact Form 7 version %2$s! Use %3$s instead.'=>'Hook %1$s自Contact Form 7 %2$s版本起已<strong>弃用</strong>！请改用%3$s。','Flamingo'=>'Flamingo','Install a message storage plugin before this happens to you. %s saves all messages through contact forms into the database. Flamingo is a free WordPress plugin created by the same author as Contact Form 7.'=>'发生这种情况之前，请安装消息存储插件。%s 将把联系表格的所有消息保存到数据库。
Flamingo是由Contact Form 7同一作者所 创建一个免费的 WordPress 插件。','Contact Form 7 does not store submitted messages anywhere. Therefore, you may lose important messages forever if your mail server has issues or you make a mistake in mail configuration.'=>'Contact Form 7不会在任何地方存储已提交的消息。因此，如果您的邮件服务器出现问题或您在邮件配置中出现错误，您可能会永久失去重要的消息。','Before you cry over spilt mail&#8230;'=>'在您为邮件泄露而伤心痛哭之前&#8230;','https://contactform7.com/comment-blacklist/'=>'https://contactform7.com/comment-blacklist/','Contact Form 7 supports spam-filtering with %1$s. Intelligent %2$s blocks annoying spambots. Plus, using %3$s, you can block messages containing specified keywords or those sent from specified IP addresses.'=>'Contact Form 7 以%1$s支持垃圾邮件过滤。智能 %2$s 能阻止垃圾机器人。另外，使用 %3$s，您可以阻止包含指定的关键字或那些从指定的 IP 地址发送的邮件。','Spammers target everything; your contact forms are not an exception. Before you get spammed, protect your contact forms with the powerful anti-spam features Contact Form 7 provides.'=>'垃圾邮件发送者会攻击所有东西；您的联系表单也不例外。在您被垃圾邮件攻击之前，请使用Contact Form 7提供的强大反垃圾邮件功能来保护您的联系表单。','Getting spammed? You have protection.'=>'收到垃圾邮件？您有保护。','Multiple form controls are in a single label element.'=>'多个表单控件都放在一个单独的标签元素中。','FAQ about Configuration Validator'=>'有关配置检验的常见问题','https://contactform7.com/configuration-validator-faq/'=>'https://contactform7.com/configuration-validator-faq/','The answer to the quiz is incorrect.'=>'小测验的答案不正确。','There was an error uploading the file.'=>'上传文件时出错。','You are not allowed to upload files of this type.'=>'抱歉，不允许上传这一类型的文件。','There was an unknown error uploading the file.'=>'上传文件时出错。','You must accept the terms and conditions before sending your message.'=>'您必须阅读并接受条款和条件，才能发送信息。','One or more fields have an error. Please check and try again.'=>'出现错误，请检查后重新尝试。','There was an error trying to send your message. Please try again later.'=>'发生错误，请稍后再试。','Thank you for your message. It has been sent.'=>'谢谢。已发送您的信息。','mail subject%1$s "%2$s"'=>'%1$s "%2$s"','Misconfiguration leads to mail delivery failure or other troubles. Validate your contact forms now.'=>'错误的设置导致无法发送或其它问题。请立即核对您的联系表单。','Validate Contact Form 7 Configuration'=>'验证 Contact Form 7 配置','https://contactform7.com/configuration-errors/'=>'https://contactform7.com/configuration-errors/','Configuration validation completed. No invalid contact form was found.'=>'验证已完成，没有无效表单。','Configuration validation completed. %s invalid contact form was found.'=>'验证已完成，发现%s个无效表单。','Validate Configuration'=>'验证配置','Validate %s contact form now'=>'现在就验证%s联系表单','You are not allowed to validate configuration.'=>'您没有权限进行验证。','https://contactform7.com/recaptcha/'=>'https://contactform7.com/recaptcha/','Secret Key'=>'密匙','Site Key'=>'站点密钥','Settings saved.'=>'设置已保存。','Invalid key values.'=>'无效的密钥。','reCAPTCHA'=>'reCAPTCHA人机识别系统','https://ideasilo.wordpress.com/'=>'https://ideasilo.wordpress.com/','Takayuki Miyoshi'=>'Takayuki Miyoshi','Just another contact form plugin. Simple but flexible.'=>'一个联系表单插件，简单而灵活。','https://contactform7.com/'=>'https://contactform7.com/','Contact form %d'=>'联系表单 %d','text area'=>'文本段','Akismet'=>'Akismet','tel'=>'电话','URL'=>'链接','email'=>'邮箱地址','text'=>'文本','Telephone number that the sender entered is invalid'=>'发件人输入的电话号码无效','URL that the sender entered is invalid'=>'发件人输入的链接无效','Email address that the sender entered is invalid'=>'发送人输入的邮箱地址无效','Label'=>'标签','Submit button'=>'提交按钮','submit'=>'提交','drop-down menu'=>'下拉式菜单','Questions and answers'=>'问题与解答','Quiz'=>'小测验','quiz'=>'测验','Sender does not enter the correct answer to the quiz'=>'发件人没有输入正确的问答验证答案。','Slider'=>'轮播图','Spinbox'=>'Spinbox','number'=>'数值','Number is larger than maximum limit'=>'数字大于上限','Number is smaller than minimum limit'=>'数字小于下限','Number format that the sender entered is invalid'=>'发送者输入的数字格式无效','This contact form has file uploading fields, but the temporary folder for the files (%s) does not exist or is not writable. You can create the folder or change its permission manually.'=>'此联系表单有文件上传字段，但文件的临时文件夹(%s)不存在或不可写。您可以手动创建文件夹或更改其权限。','Acceptable file types'=>'可上传的文件类型','file'=>'文件','Uploading a file fails for PHP error'=>'因为PHP错误，上传文件失败','Uploaded file is too large'=>'上传的文件太大','Uploaded file is not allowed for file type'=>'上传的文件是不允许的文件类型','Uploading a file fails for any reason'=>'由于某种原因上传文件失败','Max'=>'最大','Min'=>'最小','Range'=>'范围','Default value'=>'默认值','Date field'=>'日期字段','date'=>'日期','Date is later than maximum limit'=>'日期值大于最大允许日期值','Date is earlier than minimum limit'=>'日期值小于最小日期值','Date format that the sender entered is invalid'=>'发件人输入的日期格式不正确','Field type'=>'字段类型','radio buttons'=>'单选按钮','checkboxes'=>'复选框','This contact form contains CAPTCHA fields, but the necessary libraries (GD and FreeType) are not available on your server.'=>'这个联系表单包含CAPTCHA域，但是您的服务器上没有必须要用到的库（GD and FreeType）。','This contact form contains CAPTCHA fields, but the temporary folder for the files (%s) does not exist or is not writable. You can create the folder or change its permission manually.'=>'这个联系表单包含CAPTCHA域，但包含文件(%s)的临时文件夹不存在或者没法写入。您可以创建文件夹或者手动修改权限。','Your entered code is incorrect.'=>'您输入的验证码不正确。','The code that sender entered does not match the CAPTCHA'=>'发件人输入的验证码和CAPTCHA的不匹配','Insert Tag'=>'插入标签','Class attribute'=>'样式属性','Acceptance checkbox'=>'接受复选框','acceptance'=>'接受','<code>%1$s</code> property of a <code>WPCF7_ContactForm</code> object is <strong>no longer accessible</strong>. Use <code>%2$s</code> method instead.'=>'<code>WPCF7_ContactForm</code> 对象的<code>%1$s</code>属性 <strong>已经废除</strong>。请使用<code>%2$s</code>代替。','Untitled'=>'没有标题','Contact Form'=>'联系表单','There is a field with input that is shorter than the minimum allowed length'=>'一个字段的输入短于最小允许长度','There is a field with input that is longer than the maximum allowed length'=>'一个字段输入超过最大允许长度','There is a field that the sender must fill in'=>'发件人必须填写必填项','There are terms that the sender must accept'=>'有些选项发件人必须同意接受','Submission was referred to as spam'=>'提交的邮件被归为垃圾邮件','Validation errors occurred'=>'出现验证错误','Sender\'s message failed to send'=>'发件人的邮件发送失败','Sender\'s message was sent successfully'=>'发件人的邮件已经成功发送','Message Body:'=>'消息正文：','Subject: %s'=>'主题：%s','From: %s'=>'发件人：%s','Send'=>'发送','Your message'=>'您的消息','Your email'=>'您的电邮','Your name'=>'您的名字','Form-tag Generator: %s'=>'Form标签创建：%s','For more information:'=>'想要了解详细情况：','Any information you provide will not be shared with service providers without your authorization.'=>'您所提供的信息未经您同意不会与服务供应商分享。','You may need to first sign up for an account with the service that you plan to use. When you do so, you would need to authorize Contact Form 7 to access the service with your account.'=>'您需要创建帐号以使用服务。创建时，请同时授权Contact Form 7访问您的帐号。','On this screen, you can manage services that are available through Contact Form 7. Using API will allow you to collaborate with any services that are available.'=>'在当前屏幕，您可以管理Contact Form7有关的服务。使用API来进行相关操作。','There are also special mail-tags that have specific names, but do not have corresponding form-tags. They are used to represent meta information of form submissions like the submitter&#8217;s IP address or the URL of the page.'=>'还有一些特殊的邮件标签，它们有特定的名称，但没有相应的表单标签。它们用于表示表单提交的元信息，例如提交者的IP地址或页面的URL。','A mail-tag is also a short code enclosed in square brackets that you can use in every Mail and Mail (2) field. A mail-tag represents a user input value through an input field of a corresponding form-tag.'=>'邮件标签也是置于方括号中的短代码，您可以使用在邮件和邮件 (2) 字段。邮件标签表示用户通过相应的form标签输入字段的输入值。','While form-tags have a comparatively complex syntax, you do not need to know the syntax to add form-tags because you can use the straightforward tag generator (<strong>Generate Tag</strong> button on this screen).'=>'虽然表单标签有相对复杂的语法，但您不需要知道这种语法来添加表单标签，因为您可以使用简单的标签生成器（此屏幕上的<strong>生成标签</strong>按钮）。','A form-tag is a short code enclosed in square brackets used in a form content. A form-tag generally represents an input field, and its components can be separated into four parts: type, name, options, and values. Contact Form 7 supports several types of form-tags including text fields, number fields, date fields, checkboxes, radio buttons, menus, file-uploading fields, CAPTCHAs, and quiz fields.'=>'Form标签是在表单内容中的方括号内的简码（short code）。Form标签通常表示一个输入的字段，其组件可以分成四个部分︰ 类型、 名称、 选项和值。Contact Form 7 支持多种类型的表单,包括文本字段、数字字段、日期字段、复选框、单选按钮、菜单、文件上传字段，验证码，和测验字段。','<strong>Additional Settings</strong> provides a place where you can customize the behavior of this contact form by adding code snippets.'=>'<strong>其它设置</strong>提供了使用码段来改变联系表单的方法。','In <strong>Messages</strong>, you can edit various types of messages used for this contact form. These messages are relatively short messages, like a validation error message you see when you leave a required field blank.'=>'在 <strong>邮件信息</strong> 中，您可以编辑各种类型的消息用于此联系表单。这些消息都是相对较短的消息，比如您看到必填的字段为空时的验证错误消息。','<strong>Mail (2)</strong> is an additional mail template that works similar to Mail. Mail (2) is different in that it is sent only when Mail has been sent successfully.'=>'<strong>邮件(2)</strong> 是一个类似于邮件（Mail）的附加的邮件模板。邮件(2) 不同的是它只有当邮件（Mail）已成功发送时发送。','<strong>Mail</strong> manages a mail template (headers and message body) that this contact form will send when users submit it. You can use Contact Form 7&#8217;s mail-tags here.'=>'<strong>邮件</strong> 是一个模板文件（邮件标题和邮件正文），用户提交联系表单时，它将发送该邮件模板。您可以在此使用Contact form 7的邮件标签。','<strong>Form</strong> is a content of HTML form. You can use arbitrary HTML, which is allowed inside a form element. You can also use Contact Form 7&#8217;s form-tags here.'=>'<strong>表单</strong> 是HTML表单的内容。您可以在form元素内使用任意的HTML。您还可以在这里使用Contact Form 7的form标签。','<strong>Title</strong> is the title of a contact form. This title is only used for labeling a contact form, and can be edited.'=>'<strong>标题</strong>是联系表单的标题。标题用于标记该表单，并可进行编辑。','On this screen, you can edit a contact form. A contact form is comprised of the following components:'=>'在该屏幕可以进行联系表单的编辑。联系表单由以下部分组成：','<strong>Duplicate</strong> - Clones that contact form. A cloned contact form inherits all content from the original, but has a different ID.'=>'<strong>复制</strong> -复制表单。复制的表单与原表单内容一致，但ID不同。','<strong>Edit</strong> - Navigates to the editing screen for that contact form. You can also reach that screen by clicking on the contact form title.'=>'<strong>编辑</strong> -打开联系表单编辑屏幕。您也可以单击联系表单进入编辑状态。','Hovering over a row in the contact forms list will display action links that allow you to manage your contact form. You can perform the following actions:'=>'悬停在联系表单中的某一行将显示允许您管理您的联系表单的操作链接。您可以执行以下操作:','On this screen, you can manage contact forms provided by Contact Form 7. You can manage an unlimited number of contact forms. Each contact form has a unique ID and Contact Form 7 shortcode ([contact-form-7 ...]). To insert a contact form into a post or a text widget, insert the shortcode into the target.'=>'在此屏幕上，您可以管理Contact Form7提供的所有表单。您可以管理无限数量的。每个联表单。每一个表单有唯一的ID和Contact Form 7 简码 ([contact-form-7...])。若要在文章或小工具中插入联系表单，只需要输入简码即可。','Mail-tags'=>'Mail标签','Form-tags'=>'表单form标签','Available Actions'=>'可进行的操作','Overview'=>'概述','You can add customization code snippets here. For details, see %s.'=>'您可在此插入自訂代码。详细方式可參考 %s 。','https://contactform7.com/additional-settings/'=>'https://contactform7.com/additional-settings/','File attachments'=>'文件附件','Use HTML content type'=>'使用HTML内容类型','Exclude lines with blank mail-tags from output'=>'不输出空白邮件标签行','Message body'=>'消息正文','Additional headers'=>'附加标题','Subject'=>'主题','From'=>'发件人','To'=>'收件人','In the following fields, you can use these mail-tags:'=>'下面空格中，您可以使用這些邮件标签:','Mail (2) is an additional mail template often used as an autoresponder.'=>'邮箱（2）通常用作自动回复的模板。','Use Mail (2)'=>'使用 Mail (2)','Mail (2)'=>'邮箱（2）','Y/m/d'=>'年/月/日','Edit &#8220;%s&#8221;'=>'编辑 &#8220;%s&#8221;','Edit'=>'编辑','Date'=>'日期','Author'=>'作者','Shortcode'=>'简码','Title'=>'标题','Additional Settings'=>'额外的设置','Additional Settings (%d)'=>'附加的设置 (%d)','Messages'=>'留言','Mail'=>'邮箱','Form'=>'表单','Support'=>'支持','https://contactform7.com/support/'=>'https://contactform7.com/support/','FAQ'=>'常见问题解答','https://contactform7.com/faq/'=>'https://contactform7.com/faq/','Docs'=>'文档','https://contactform7.com/docs/'=>'https://contactform7.com/docs/','Delete'=>'删除','Duplicate'=>'复制','Status'=>'状态','You can also use this old-style shortcode:'=>'也可使用旧式短代码：','Copy this shortcode and paste it into your post, page, or text widget content:'=>'复制此“短代码并粘贴到您的文章，页面，或文字小工具中:','Enter title here'=>'在此输入标题','Save'=>'保存','You are not allowed to edit this contact form.'=>'您没有编辑此项目的权限。','https://contactform7.com/save-submitted-messages-with-flamingo/'=>'https://contactform7.com/save-submitted-messages-with-flamingo/','Spam filtering with Akismet'=>'使用Akismet进行垃圾邮件过滤。','https://contactform7.com/spam-filtering-with-akismet/'=>'https://contactform7.com/spam-filtering-with-akismet/','Setting up mail'=>'设置电邮','https://contactform7.com/setting-up-mail/'=>'https://contactform7.com/setting-up-mail/','Contact Form 7 needs your support.'=>'Contact Form 7需要您的支持。','Dismiss'=>'取消','<strong>Contact Form 7 %1$s requires WordPress %2$s or higher.</strong> Please <a href="%3$s">update WordPress</a> first.'=>'<strong>Contact Form 7 %1$s 需要 WordPress %2$s 或更高版本。</strong> 请<a href="%3$s">先更新WordPress</a>。','Settings'=>'设置','Contact form deleted.'=>'联系表单已删除。','Contact form saved.'=>'联系表已单保存。','Contact form created.'=>'联系表单已创建。','Search Contact Forms'=>'搜索联系表单','Search results for &#8220;%s&#8221;'=>' &#8220;%s&#8221; 的搜索结果','Error in deleting.'=>'删除时出错。','You are not allowed to delete this item.'=>'您没有删除权限。','You are not allowed to edit this item.'=>'您没有编辑此项目的权限。','Integration'=>'整合','Add New'=>'添加新表单','Add New Contact Form'=>'创建新的联系表单','Contact Forms'=>'联系表单','Edit Contact Form'=>'编辑联系表单','Contact'=>'联系','Contact Form 7'=>'Contact Form 7']];