<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2025-11-26 01:39:19+0000','plural-forms'=>'nplurals=1; plural=0;','project-id-version'=>'Plugins - Hello Dolly - Stable (latest release)','language'=>'ko_KR','messages'=>['https://ma.tt/'=>'https://ma.tt/','Matt Mullenweg'=>'메트 뮐렌베그','This is not just a plugin, it symbolizes the hope and enthusiasm of an entire generation summed up in two words sung most famously by Louis Armstrong: Hello, Dolly. When activated you will randomly see a lyric from <cite>Hello, Dolly</cite> in the upper right of your admin screen on every page.'=>'단순한 플러그인이 아니라, 루이 암스트롱이 불러 가장 유명한 헬로, 달리 이 두 단어에 전 세대를 아우르는 희망과 열정을 상징화했어요. 활성화하면 매 페이지의 관리화면의 오른쪽 위에 <cite>헬로, 달리</cite>의 무작위 가사를 보게 될 거에요.','https://wordpress.org/plugins/hello-dolly/'=>'https://wordpress.org/plugins/hello-dolly/','Hello Dolly'=>'Hello Dolly']];