<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-08-05 08:34:12+0000','plural-forms'=>'nplurals=2; plural=n > 1;','project-id-version'=>'Plugins - Contact Form 7 - Stable (latest release)','language'=>'id','messages'=>['There is no valid unit tag.'=>'Tidak ada tag unit yang valid.','Brevo integration'=>'Integrasi Brevo','This email is a receipt for your contact form submission on our website (%1$s %2$s) in which your email address was used. If that was not you, please ignore this message.'=>'Email ini adalah tanda terima pengiriman formulir kontak Anda di situs web kami (%1$s %2$s) yang menggunakan alamat email Anda. Jika itu bukan Anda, harap abaikan pesan ini.','This is a notification that a contact form was submitted on your website (%1$s %2$s).'=>'Ini adalah pemberitahuan bahwa formulir kontak telah dikirimkan di situs web Anda (%1$s %2$s).','Unsafe email config is used without sufficient protection.'=>'Konfigurasi email yang tidak aman digunakan tanpa perlindungan yang memadai.','Configuration error is detected.'=>'Kesalahan konfigurasi terdeteksi.','Brevo is active on this site.'=>'Brevo sudah aktif di situs ini.','Brevo'=>'Brevo','Contact form not found.'=>'Formulir kontak tidak ditemukan.','Error:'=>'Eror:','block keywordform'=>'formulir','block descriptionInsert a contact form you have created with Contact Form 7.'=>'Sisipkan formulir kontak yang telah Anda buat dengan Contact Form 7.','block titleContact Form 7'=>'Contact Form 7','&#8212;Please choose an option&#8212;'=>'&#8212;Silakan pilih salah satu opsi &#8212;','Akismet is active on this site.'=>'Akismet aktif di situs ini.','CAPTCHAs are designed to distinguish spambots from humans, and are therefore helpless against human spammers. In contrast to CAPTCHAs, Akismet checks form submissions against the global database of spam; this means Akismet is a comprehensive solution against spam. This is why we consider Akismet to be the centerpiece of the spam prevention strategy.'=>'CAPTCHA dirancang untuk membedakan spambot dari manusia, dan oleh karena itu tidak berdaya melawan spammer manusia. Berbeda dengan CAPTCHA, Akismet memeriksa kiriman formulir terhadap basis data global spam; ini berarti Akismet adalah solusi komprehensif melawan spam. Inilah mengapa kami menganggap Akismet sebagai inti dari strategi pencegahan spam.','Learn how your data is processed.'=>'Pelajari bagaimana data Anda diproses.','This form uses Akismet to reduce spam.'=>'Formulir ini menggunakan Akismet untuk mengurangi spam.','Contact form'=>'Formulir Kontak','Colons are used in form-tag names.'=>'Titik dua digunakan untuk nama form-tag.','Please enter a telephone number.'=>'Mohon masukkan nomor telepon.','Please enter a URL.'=>'Mohon masukkan URL.','Please enter an email address.'=>'Mohon masukkan alamat e-mail.','This field has a too large number.'=>'Ruas ini memiliki angka terlalu besar.','This field has a too small number.'=>'Ruas ini memiliki angka terlalu kecil.','Please enter a number.'=>'Mohon masukkan nomor.','This field has a too late date.'=>'Ruas ini memiliki tanggal yang telah lampau.','This field has a too early date.'=>'Bidang ini memiliki tanggal yang terlalu dini.','Please enter a date in YYYY-MM-DD format.'=>'Mohon masukkan tanggal dalam format TTTT-BB-HH.','The request payload format is not supported.'=>'Format request payload tidak didukung.','Hook %1$s is <strong>deprecated</strong> since Contact Form 7 version %2$s with no alternative available.'=>'Hook %1$s <strong>tidak digunakan lagi</strong> sejak Formulir Kontak 7 versi %2$s tanpa adanya alternatif yang tersedia.','The uploaded file is too large.'=>'Berkas yang diunggah terlalu besar.','This field has a too short input.'=>'Ruas ini memiliki input terlalu pendek.','This field has a too long input.'=>'Ruas ini memiliki input terlalu panjang.','Please fill out this field.'=>'Mohon isi ruas ini.','Function %1$s is <strong>deprecated</strong> since Contact Form 7 version %2$s! Use %3$s instead.'=>'Fungsi %1$s telah <strong>usang</strong> sejak Contact Form 7 versi %2$s! Gunakan %3$s sebagai gantinya.','Spam protection'=>'Proteksi spam','Function %1$s was called incorrectly. %2$s %3$s'=>'Fungsi %1$s dipanggil secara tidak benar. %2$s %3$s','Hello,

This is a confirmation email sent from %1$s.

We have received your submission to our web form, according to which you have allowed us to add you to our contact list. But, the process has not yet been completed. To complete it, please click the following link.

%2$s

If it was not your intention, or if you have no idea why you received this message, please do not click on the link, and ignore this message. We will never collect or use your personal data without your clear consent.

Sincerely,
%1$s'=>'Halo,

Ini adalah e-mail konfirmasi yang dikirim dari %1$s.

Kami telah menerima kiriman Anda ke formulir web kami, yang berarti Anda mengizinkan kami untuk menambahkan Anda ke daftar kontak kami. Tapi, prosesnya belum selesai. Untuk melengkapinya, silakan klik tautan berikut.

%2$s

Jika itu bukan keinginan Anda, atau jika Anda tidak tahu mengapa Anda menerima pesan ini, jangan klik tautan tersebut, dan abaikan pesan ini. Kami tidak akan mengumpulkan atau menggunakan data pribadi Anda tanpa persetujuan yang jelas dari Anda.

Dengan hormat,
%1$s','Opt-in confirmation from %s'=>'Konfirmasi pilih masuk dari %s','Complete payment'=>'Selesaikan pembayaran','Proceed to checkout'=>'Lanjutkan ke pembayaran','Payment is required. Please pay by credit card.'=>'Pembayaran diperlukan. Silakan lakukan pembayaran dengan kartu kredit.','Payments'=>'Pembayaran','Publishable Key'=>'Kunci yang dapat dipublikasikan','Stripe is not available on this site. It requires an HTTPS-enabled site.'=>'Stripe tidak tersedia di situs ini. Stripe membutuhkan situs yang mendukung HTTPS.','Stripe is active on this site.'=>'Stripe aktif di situs ini.','Stripe integration'=>'Integrasi Stripe','personal name%1$s %2$s'=>'%1$s %2$s','Unique identifier for the contact form.'=>'Pengidentifikasi unik untuk formulir kontak.','Dots are used in form-tag names.'=>'Titik-titik digunakan di nama-nama form-tag.','Show welcome panel'=>'Tampilkan kotak sambutan','Welcome panel'=>'Panel sambutan','Stripe'=>'Stripe','https://contactform7.com/stripe-integration/'=>'https://contactform7.com/stripe-integration/','With help from cloud-based machine learning, anti-spam services will protect your forms (%1$s). Even payment services are natively supported (%2$s).'=>'Dengan bantuan machine learning berbasis awan, layanan anti-spam akan melindungi formulir kontak Anda (%1$s). Bahkan layanan pembayaran juga didukung (%2$s).','You have strong allies to back you up.'=>'Anda punya sekutu kuat untuk membantu anda.','Integration with external APIs'=>'Integrasi dengan API eksternal','https://contactform7.com/integration-with-external-apis/'=>'https://contactform7.com/integration-with-external-apis/','You can expand the possibilities of your contact forms by integrating them with external services. For details, see %s.'=>'Anda dapat mengembangkan lebih lanjut formulir kontak anda dengan cara mengintegrasikan dengan layanan eksternal. Informasi lebih lanjut, lihat %s.','Integration with External API'=>'Integrasi dengan API Eksternal','Manage your email templates'=>'Kelola template e-mail Anda','You have no active email template yet.'=>'Anda belum memiliki template e-mail aktif.','&mdash; Select &mdash;'=>'&mdash; Pilih &mdash;','Select an email template:'=>'Pilih template e-mail:','Send a welcome email to new contacts'=>'Kirim e-mail selamat datang ke kontak baru','Welcome email'=>'E-mail selamat datang','(opens in a new tab)'=>'(buka di tab baru)','Manage your contact lists'=>'Kelola daftar kontak Anda','You have no contact list yet.'=>'Anda belum memiliki daftar kontak.','Select lists to which contacts are added:'=>'Pilih daftar yang akan ditambahkan kontak:','Add form submitters to your contact lists'=>'Tambahkan pengirim formulir ke daftar kontak Anda','Contact lists'=>'Daftar Kontak','You can set up the Brevo integration here. For details, see %s.'=>'Anda dapat mengatur integrasi Brevo di sini. Untuk detailnya, lihat %s.','Save changes'=>'Simpan perubahan','API keysRemove key'=>'Hapus kunci','API key'=>'Kunci API','Setup integration'=>'Pengaturan integrasi','https://contactform7.com/sendinblue-integration/'=>'https://contactform7.com/sendinblue-integration/','Store and organize your contacts while protecting user privacy on Brevo, the leading CRM & email marketing platform in Europe. Brevo offers unlimited contacts and advanced marketing features.'=>'Simpan dan atur kontak Anda sekaligus melindungi privasi pengguna di Brevo, platform CRM & pemasaran e-mail terkemuka di Eropa. Brevo menawarkan kontak tak terbatas dan fitur pemasaran tingkat lanjut.','You have not been authenticated. Make sure the provided API key is correct.'=>'Anda belum diautentikasi. Pastikan kunci API yang disediakan sudah benar.','Failed to attach a file. The total file size exceeds the limit of 25 megabytes.'=>'Gagal melampirkan berkas. Ukuran berkas total melebihi batas 25 megabyte.','Failed to attach a file. %s is not a readable file.'=>'Gagal melampirkan berkas. %s bukan berkas yang dapat dibaca.','Failed to attach a file. %s is not in the allowed directory.'=>'Gagal melampirkan berkas. %s tidak berada dalam direktori yang diizinkan.','Submit'=>'Kirim','(optional)'=>'(opsional)','disallowed list'=>'daftar yang tidak diizinkan','Disallowed words (%s) are used.'=>'Kata-kata yang dilarang (%s) digunakan.','Disallowed words are used.'=>'Kata-kata yang dilarang digunakan.','(This message was added in Contact Form 7 version %s.)'=>'(Pesan ini ditambahkan dalam Contact Form 7 Versi %s.)','The fourth parameter ($mail_tag) must be an instance of the WPCF7_MailTag class.'=>'Parameter keempat ($mail_tag) harus berupa instance dari class WPCF7_MailTag.','g:i a'=>'g:i a','%1$s at %2$s'=>'%1$s di %2$s','docs'=>'dokumentasi','%1$s and %2$s'=>'%1$s dan %2$s','Additional settings'=>'Pengaturan tambahan','Error'=>'Eror','The total size of attachment files is too large.'=>'Total ukuran berkas lampiran terlalu besar.','Unavailable HTML elements are used in the form template.'=>'Elemen HTML yang tidak tersedia dipakai di template formulir.','reCAPTCHA is active on this site.'=>'reCAPTCHA aktif di situs ini.','reCAPTCHA response token is empty.'=>'Token respons reCAPTCHA kosong.','Submitted nonce is invalid.'=>'Nonce yang dikirimkan tidak valid.','User-Agent string is unnaturally short.'=>'String User-Agent terlalu pendek.','reCAPTCHA score (%1$.2f) is lower than the threshold (%2$.2f).'=>'Skor reCAPTCHA (%1$.2f) lebih rendah dari ambang batas (%2$.2f).','Akismet returns a spam response.'=>'Akismet mengembalikan respons spam.','HTTP Response: %1$s %2$s %3$s from %4$s'=>'Respons HTTP: %1$s %2$s %3$s dari %4$s','Save Changes'=>'Simpan Perubahan','reCAPTCHA protects you against spam and other types of automated abuse. With Contact Form 7&#8217;s reCAPTCHA integration module, you can block abusive form submissions by spam bots.'=>'reCAPTCHA melindungi Anda terhadap spam dan jenis penyalahgunaan otomatis lainnya. Dengan modul integrasi reCAPTCHA pada Contact Form 7, Anda dapat memblokir pengiriman formulir yang tidak wajar dari bot spam.','reCAPTCHA (v3)'=>'reCAPTCHA (v3)','API keys for reCAPTCHA v3 are different from those for v2; keys for v2 do not work with the v3 API. You need to register your sites again to get new keys for v3. For details, see %s.'=>'Kunci API untuk reCAPTCHA v3 berbeda dengan kunci untuk v2; kunci untuk v2 tidak berfungsi untuk API v3. Anda perlu mendaftarkan situs-situs Anda lagi untuk mendapatkan kunci baru untuk v3. Untuk detailnya, lihat %s.','API keysRemove Keys'=>'Hapus Kunci','App Secret'=>'App Secret','API Key'=>'API Key','Constant Contact'=>'Constant Contact','Email marketing'=>'Pemasaran E-mail','It is not allowed to use files outside the wp-content directory.'=>'Tidak diizinkan menggunakan berkas di luar direktori wp-content.','Professional services'=>'Layanan profesional','https://contactform7.com/custom-development/'=>'https://contactform7.com/custom-development/','Support forums'=>'Forum dukungan','https://wordpress.org/support/plugin/contact-form-7/'=>'https://wordpress.org/support/plugin/contact-form-7/','Here are some available options to help solve your problems.'=>'Berikut adalah beberapa opsi yang tersedia untuk membantu memecahkan masalah Anda.','Do you need help?'=>'Apakah Anda membutuhkan bantuan?','Condition'=>'Kondisi','mail output for acceptance checkboxes%1$s: %2$s'=>'%1$s: %2$s','Not consented'=>'Tidak disetujui','Consented'=>'Setuju','Sending mail has been aborted.'=>'Pengiriman email telah dibatalkan.','You can edit messages used in various situations here. For details, see %s.'=>'Anda dapat mengedit pesan yang digunakan dalam berbagai situasi di sini. Untuk detailnya, lihat %s.','Editing messages'=>'Mengedit pesan','https://contactform7.com/editing-messages/'=>'https://contactform7.com/editing-messages/','You can edit the mail template here. For details, see %s.'=>'Anda dapat mengedit template e-mail di sini. Untuk detailnya, lihat %s.','You can edit the form template here. For details, see %s.'=>'Anda dapat mengedit template formulir di sini. Untuk detailnya, lihat %s.','Editing form template'=>'Edit template formulir','https://contactform7.com/editing-form-template/'=>'https://contactform7.com/editing-form-template/','This contact form is available only for logged in users.'=>'Formulir kontak ini hanya tersedia untuk pengguna yang sudah login.','Deprecated settings are used.'=>'Pengaturan usang digunakan.','To use CAPTCHA, you need %s plugin installed.'=>'Untuk menggunakan CAPTCHA, Anda perlu plugin %s diinstal.','There was an error deleting the contact form.'=>'Ada eror menghapus formulir kontak.','You are not allowed to access the requested contact form.'=>'Anda tidak diizinkan untuk mengakses formulir kontak yang diminta.','The requested contact form was not found.'=>'Formulir kontak yang diminta tidak ditemukan.','You are not allowed to create a contact form.'=>'Anda tidak diizinkan untuk membuat formulir kontak.','Cannot create existing contact form.'=>'Tidak bisa membuat formulir kontak yang sudah ada.','You are not allowed to access contact forms.'=>'Anda tidak diizinkan untuk mengakses formulir kontak.','Attachment file does not exist at %path%.'=>'Berkas lampiran tidak ada di %path%.','Invalid mailbox syntax is used in the %name% field.'=>'Sintaks kotak surat yang tidak valid digunakan di bidang %name%.','Unavailable names (%names%) are used for form controls.'=>'Nama yang tidak tersedia (%names%) digunakan untuk kontrol formulir.','There are invalid mail header fields.'=>'Ada bidang header e-mail yang tidak valid.','HTML tags are used in a message.'=>'Tag HTML digunakan dalam sebuah pesan.','Sender email address does not belong to the site domain.'=>'Alamat e-mail pengirim tidak sesuai dengan domain situs ini.','Invalid mailbox syntax is used.'=>'Syntax kotak surat yang tidak valid digunakan.','There is a possible empty field.'=>'Ada kemungkinan kolom kosong.','%s configuration error detected'=>'%s eror konfigurasi terdeteksi' . "\0" . '%s eror konfigurasi terdeteksi','There was an error saving the contact form.'=>'Ada kesalahan menyimpan formulir kontak.','Hook %1$s is <strong>deprecated</strong> since Contact Form 7 version %2$s! Use %3$s instead.'=>'Hook %1$s telah <strong>usang</strong> sejak Contact Form 7 versi %2$s! Gunakan %3$s sebagai gantinya.','Flamingo'=>'Flamingo','Install a message storage plugin before this happens to you. %s saves all messages through contact forms into the database. Flamingo is a free WordPress plugin created by the same author as Contact Form 7.'=>'Instal plugin penyimpan pesan sebelum hal tersebut terjadi pada Anda. %s menyimpan semua pesan dari formulir kontak ke basis data. Flamingo adalah plugin WordPress gratis yang diciptakan oleh developer yang sama dari Contact Form 7.','Contact Form 7 does not store submitted messages anywhere. Therefore, you may lose important messages forever if your mail server has issues or you make a mistake in mail configuration.'=>'Contact Form 7 tidak menyimpan pesan di mana pun. Jadi, Anda akan kehilangan pesan penting selamanya jika server pesan Anda bermasalah atau Anda membuat kesalahan dalam konfigurasi pesan.','Before you cry over spilt mail&#8230;'=>'Sebelum Anda menangisi surat yang hilang&#8230;','https://contactform7.com/comment-blacklist/'=>'https://contactform7.com/comment-blacklist/','Spammers target everything; your contact forms are not an exception. Before you get spammed, protect your contact forms with the powerful anti-spam features Contact Form 7 provides.'=>'Spammer menargetkan segalanya; formulir kontak Anda tidak terkecuali. Sebelum Anda terkena spam, lindungi formulir kontak Anda dengan fitur anti-spam canggih yang disediakan Contact Form 7.','Getting spammed? You have protection.'=>'Kena spam? Anda memiliki perlindungan.','Multiple form controls are in a single label element.'=>'Kontrol multi form ada dalam sebuah label elemen','FAQ about Configuration Validator'=>'FAQ tentang Validator Konfigurasi','https://contactform7.com/configuration-validator-faq/'=>'https://contactform7.com/configuration-validator-faq/','The answer to the quiz is incorrect.'=>'Jawaban untuk kuis tidak benar.','There was an error uploading the file.'=>'Terdapat kesalahan dalam mengunggah berkas','You are not allowed to upload files of this type.'=>'Anda tidak diperbolehkan untuk mengunggah berkas dengan jenis ini.','There was an unknown error uploading the file.'=>'Terdapat kesalahan tidak diketahui saat mengunggah berkas.','You must accept the terms and conditions before sending your message.'=>'Anda harus menerima syarat dan ketentuan sebelum mengirim pesan Anda.','One or more fields have an error. Please check and try again.'=>'Satu atau lebih kolom terdapat eror. Harap periksa dan coba lagi.','There was an error trying to send your message. Please try again later.'=>'Terdapat kesalahan dalam mengirim pesan Anda. Silahkan coba lagi nanti','Thank you for your message. It has been sent.'=>'Terima kasih untuk pesan Anda. Pesan berhasil dikirim','mail subject%1$s "%2$s"'=>'%1$s "%2$s"','Misconfiguration leads to mail delivery failure or other troubles. Validate your contact forms now.'=>'Kesalahan konfigurasi menyebabkan kegagalan pengiriman surat atau masalah lainnya. Validasi formulir kontak Anda sekarang.','Validate Contact Form 7 Configuration'=>'Validasi Konfigurasi Contact Form 7','https://contactform7.com/configuration-errors/'=>'https://contactform7.com/configuration-errors/','Configuration validation completed. No invalid contact form was found.'=>'Validasi konfigurasi selesai. Tidak ditemukan formulir kontak yang tidak valid.','Configuration validation completed. %s invalid contact form was found.'=>'Validasi konfigurasi selesai. Ditemukan %s formulir kontak yang tidak valid.' . "\0" . 'Validasi konfigurasi selesai. Ditemukan %s formulir kontak yang tidak valid.','Validate Configuration'=>'Validasi Konfigurasi','Validate %s contact form now'=>'Validasi %s Kontak Form Sekarang' . "\0" . 'Validasi %s Kontak Form Sekarang','You are not allowed to validate configuration.'=>'Anda tidak diizinkan untuk memvalidasi konfigurasi.','https://contactform7.com/recaptcha/'=>'https://contactform7.com/recaptcha/','Secret Key'=>'Kunci Rahasia','Site Key'=>'Kunci Situs','Settings saved.'=>'Pengaturan disimpan.','Invalid key values.'=>'Nilai kunci tidak valid.','reCAPTCHA'=>'reCAPTCHA','https://ideasilo.wordpress.com/'=>'https://ideasilo.wordpress.com/','Takayuki Miyoshi'=>'Takayuki Miyoshi','Just another contact form plugin. Simple but flexible.'=>'Hanya sekadar plugin formulir kontak lainnya. Sederhana tetapi fleksibel.','https://contactform7.com/'=>'https://contactform7.com/','Contact form %d'=>'Formulir kontak %d','text area'=>'area teks','Akismet'=>'Akismet','tel'=>'tel','URL'=>'URL','email'=>'e-mail','text'=>'teks','Telephone number that the sender entered is invalid'=>'Nomor telepon yang dimasukkan pengirim tidak valid','URL that the sender entered is invalid'=>'URL yang dimasukkan oleh pengirim tidak valid','Email address that the sender entered is invalid'=>'Alamat e-mail yang dimasukkan oleh pengirim tidak valid','Label'=>'Label','Submit button'=>'Tombol Kirim','submit'=>'kirim','drop-down menu'=>'drop-down menu','Questions and answers'=>'Pertanyaan dan jawaban','Quiz'=>'Kuis','quiz'=>'kuis','Sender does not enter the correct answer to the quiz'=>'Pengirim tidak memasukkan jawaban yang benar untuk kuis','Slider'=>'Slider','Spinbox'=>'Spinbox','number'=>'angka','Number is larger than maximum limit'=>'Angka lebih besar dari batas maksimum','Number is smaller than minimum limit'=>'Angka lebih kecil dari batas minimum','Number format that the sender entered is invalid'=>'Format angka yang dimasukkan oleh pengirim tidak valid','This contact form has file uploading fields, but the temporary folder for the files (%s) does not exist or is not writable. You can create the folder or change its permission manually.'=>'Formulir kontak ini mengandung ruas untuk mengunggah berkas, tapi folder sementara untuk berkas (%s) belum ada atau tidak bisa ditulis. Anda bisa membuat foldernya atau mengubah ijinnya secara manual.','Acceptable file types'=>'Jenis berkas yang dapat diterima','file'=>'berkas','Uploading a file fails for PHP error'=>'Pengunggahan gagal karena galat PHP','Uploaded file is too large'=>'Berkas yang diunggah terlalu besar','Uploaded file is not allowed for file type'=>'Berkas yang diunggah bukan jenis yang diperbolehkan','Uploading a file fails for any reason'=>'Pengunggahan berkas gagal karena suatu sebab.','Max'=>'Maks','Min'=>'Min','Range'=>'Range','Default value'=>'Nilai standar','Date field'=>'Kolom Tanggal','date'=>'tanggal','Date is later than maximum limit'=>'Tanggal lebih dari batas maksimum','Date is earlier than minimum limit'=>'Tanggal kurang dari batas minimum','Date format that the sender entered is invalid'=>'Format tanggal yang dimasukkan oleh pengirim tidak valid','Field type'=>'Tipe bidang','radio buttons'=>'tombol radio','checkboxes'=>'checkbox','This contact form contains CAPTCHA fields, but the necessary libraries (GD and FreeType) are not available on your server.'=>'Formulir kontak ini mengandung ruas isian CAPTCHA, tapi pustaka yang diperlukan (GD dan FreeType) tidak tersedia pada server Anda.','This contact form contains CAPTCHA fields, but the temporary folder for the files (%s) does not exist or is not writable. You can create the folder or change its permission manually.'=>'Formulir kontak ini mengandung ruas CAPTCHA, namun folder sementara untuk berkas-berkas (%s) belum ada atau tidak bisa ditulis. Anda bisa membuat foldernya atau mengubah ijinnya secara manual.','Your entered code is incorrect.'=>'Kode yang Anda masukkan tidak benar.','The code that sender entered does not match the CAPTCHA'=>'Kode yang dimasukkan tidak sesuai dengan CAPTCHA','Insert Tag'=>'Masukkan Tag','Class attribute'=>'Atribut Class','Acceptance checkbox'=>'Checkbox Persetujuan','acceptance'=>'persetujuan','<code>%1$s</code> property of a <code>WPCF7_ContactForm</code> object is <strong>no longer accessible</strong>. Use <code>%2$s</code> method instead.'=>'Properti <code>%1$s</code> dari objek <code>WPCF7_ContactForm</code> <strong>tidak lagi dapat diakses</strong>. Gunakan metode <code>%2$s</code> sebagai gantinya.','Untitled'=>'Tanpa judul','Contact Form'=>'Formulir Kontak','There is a field with input that is shorter than the minimum allowed length'=>'Ada kolom dengan input yang lebih pendek dari yang diizinkan','There is a field with input that is longer than the maximum allowed length'=>'Ada kolom dengan input yang lebih panjang dari yang diizinkan','There is a field that the sender must fill in'=>'Ada kolom yang harus diisi oleh pengirim','There are terms that the sender must accept'=>'Ada peraturan yang harus disetujui oleh pengirim','Submission was referred to as spam'=>'Pengiriman telah ditandai sebagai spam','Validation errors occurred'=>'Timbul eror validasi','Message Body:'=>'Isi Pesan:','Subject: %s'=>'Subjek: %s','From: %s'=>'Dari: %s','Send'=>'Kirim','Your message'=>'Pesan Anda','Your email'=>'E-mail anda','Your name'=>'Nama Anda','Form-tag Generator: %s'=>'Pembuat Form-tag: %s','For more information:'=>'Untuk informasi lebih lanjut:','Any information you provide will not be shared with service providers without your authorization.'=>'Setiap informasi yang Anda berikan tidak akan dibagikan kepada penyedia layanan tanpa persetujuan Anda','You may need to first sign up for an account with the service that you plan to use. When you do so, you would need to authorize Contact Form 7 to access the service with your account.'=>'Anda mungkin perlu terlebih dulu mendaftarkan akun pada layanan yang ingin Anda gunakan. Jika Anda melakukannya, Anda akan perlu memberikan otorisasi Contact Form 7 untuk mengakses layanan menggunakan akun Anda','On this screen, you can manage services that are available through Contact Form 7. Using API will allow you to collaborate with any services that are available.'=>'Pada layar ini, Anda dapat mengelola layanan yang tersedia melalui Contact Form 7. Menggunakan API akan mengizinkan Anda untuk berkolaborasi dengan layanan lain yang tersedia.','There are also special mail-tags that have specific names, but do not have corresponding form-tags. They are used to represent meta information of form submissions like the submitter&#8217;s IP address or the URL of the page.'=>'Ada juga mail-tags spesial yang memiliki nama spesifik, tetapi tidak mempunyai form-tags yang sesuai. Mereka digunakan untuk mewakili informasi meta dari kiriman form seperti alamat IP pengirim atau URL laman.','A mail-tag is also a short code enclosed in square brackets that you can use in every Mail and Mail (2) field. A mail-tag represents a user input value through an input field of a corresponding form-tag.'=>'Mail-tag juga merupakan sebuah kode pendek tertutup dalam kurung kotak yang dapat Anda gunakan dalam setiap kolom Pesan dan Pesan (2). Mail-tag mewakili nilai input pengguna melalui kolom input dari form-tag yang sesuai. ','While form-tags have a comparatively complex syntax, you do not need to know the syntax to add form-tags because you can use the straightforward tag generator (<strong>Generate Tag</strong> button on this screen).'=>'Meski form-tags memiliki syntax yang komplek, Anda tidak perlu memahami syntax untuk menambahkan form-tags karena Anda dapat menggunakan tombol pembuat tag langsung (<strong>Buat Tag</strong> pada layar ini).','A form-tag is a short code enclosed in square brackets used in a form content. A form-tag generally represents an input field, and its components can be separated into four parts: type, name, options, and values. Contact Form 7 supports several types of form-tags including text fields, number fields, date fields, checkboxes, radio buttons, menus, file-uploading fields, CAPTCHAs, and quiz fields.'=>'Form-tag juga merupakan sebuah kode pendek tertutup dalam kurung kotak yang digunakan dalam konten form. Sebuah form-tag biasanya mewakili dari kolom input, dan komponen ini dapat dipisahkan dalam 4 bagian: tipe, nama, opsi, dan nilai. Contact Form 7 mendukung berbagai tipe form-tag termasuk kolom teks, kolom nomor, kolom tanggal, checkbox, tombol radio, menu, kolom unggah berkas, CAPTCHA, dan kolom kuis.','<strong>Additional Settings</strong> provides a place where you can customize the behavior of this contact form by adding code snippets.'=>'<strong>Pengaturan Tambahan</strong> menyediakan sebuah lokasi di mana Anda dapat menyesuaikan perilaku formulir kontak dengan menambahkan potongan kode.','In <strong>Messages</strong>, you can edit various types of messages used for this contact form. These messages are relatively short messages, like a validation error message you see when you leave a required field blank.'=>'Dalam <strong>Pesan</strong>, Anda dapat mengedit berbagai tipe pesan yang digunakan untuk formulir kontak ini. Pesan ini relatif singkat, seperti pesan kesalahan validasi yang Anda lihat ketika Anda tidak mengisi kolom wajib.','<strong>Mail (2)</strong> is an additional mail template that works similar to Mail. Mail (2) is different in that it is sent only when Mail has been sent successfully.'=>'<strong>Pesan (2)</strong> ini adalah templat pesan tambahan yang bekerja seperti Pesan. Pesan (2) berbeda dalam hal, dia hanya dikirim jika pesan utama berhasil terkirim.','<strong>Mail</strong> manages a mail template (headers and message body) that this contact form will send when users submit it. You can use Contact Form 7&#8217;s mail-tags here.'=>'<strong>Surat</strong> kelola template surat (kepala dan badan pesan) yang formulir kontak ini akan kirim ketika pengguna mengirimnya. Anda dapat menggunakan mail-tag Contact Form 7 disini','<strong>Form</strong> is a content of HTML form. You can use arbitrary HTML, which is allowed inside a form element. You can also use Contact Form 7&#8217;s form-tags here.'=>'<strong>Formulir</strong> adalah sebuah konten dari formulir HTML. Anda dapat menggunakan HTML bebas, yang diizinkan dalam sebuah elemen formulir. Anda dapat juga menggunakan form-tag Contact Form 7 di sini.','<strong>Title</strong> is the title of a contact form. This title is only used for labeling a contact form, and can be edited.'=>'<strong>Judul</strong> adalah judul dari formulir kontak. Judul ini hanya digunakan untuk memberi label sebuah formulir kontak, dan dapat diedit.','On this screen, you can edit a contact form. A contact form is comprised of the following components:'=>'Di layar ini, Anda dapat mengedit formulir kontak. Sebuah formulir kontak terdiri dari komponen-komponen berikut:','<strong>Duplicate</strong> - Clones that contact form. A cloned contact form inherits all content from the original, but has a different ID.'=>'<strong>Duplikasi</strong> - Menggandakan formulir kontak. Duplikat formulir kontak akan memiliki semua konten sama dengan yang asli, tetapi memiliki ID yang berbeda.','<strong>Edit</strong> - Navigates to the editing screen for that contact form. You can also reach that screen by clicking on the contact form title.'=>'<strong>Edit</strong> - Pergi ke layar pengeditan formulir kontak. Anda juga dapat mencapainya dengan klik pada judul formulir kontak.','Hovering over a row in the contact forms list will display action links that allow you to manage your contact form. You can perform the following actions:'=>'Menyorot baris dalam daftar formulir kontak akan memunculkan tautan aksi yang memungkinkan Anda untuk mengelola formulir kontak Anda. Anda dapat menjalankan aksi berikut: ','On this screen, you can manage contact forms provided by Contact Form 7. You can manage an unlimited number of contact forms. Each contact form has a unique ID and Contact Form 7 shortcode ([contact-form-7 ...]). To insert a contact form into a post or a text widget, insert the shortcode into the target.'=>'Pada layar ini, Anda dapat mengelola formulir kontak yang disediakan oleh Contact Form 7. Anda dapat mengelola formulir kontak dalam jumlah tak terbatas. Setiap formulir kontak memiliki sebuah ID unik dan shortcode Contact Form 7 ([contact-form-7 ...]). Untuk memasukkan formulir kontak ke dalam pos atau widget teks, masukan shortcode ke dalam target.','Mail-tags'=>'Mail-tag','Form-tags'=>'Form-tag','Available Actions'=>'Tindakan Yang Tersedia','Overview'=>'Ikhtisar','You can add customization code snippets here. For details, see %s.'=>'Anda dapat menambahkan kode khusus di sini. Untuk detail, lihat %s.','https://contactform7.com/additional-settings/'=>'https://contactform7.com/additional-settings/','File attachments'=>'Lampiran berkas','Use HTML content type'=>'Gunakan tipe konten HTML','Exclude lines with blank mail-tags from output'=>'Jangan sertakan baris dengan mail-tag kosong dalam output','Message body'=>'Isi pesan','Additional headers'=>'Header tambahan','Subject'=>'Subjek','From'=>'Dari','To'=>'Kepada','In the following fields, you can use these mail-tags:'=>'Dalam kolom berikut, Anda dapat menggunakan mail-tag berikut:','Mail (2) is an additional mail template often used as an autoresponder.'=>'Surat (2) adalah sebuah tambahan template surat yang sering digunakan sebagai balasan otomatis.','Use Mail (2)'=>'Gunakan Surat (2)','Mail (2)'=>'Surat (2)','Y/m/d'=>'Y/m/d','Edit &#8220;%s&#8221;'=>'Sunting &#8220;%s&#8221;','Edit'=>'Edit','Date'=>'Tanggal','Author'=>'Penulis','Shortcode'=>'Shortcode','Title'=>'Judul','Additional Settings'=>'Pengaturan Tambahan','Additional Settings (%d)'=>'Pengaturan Tambahan (%d)','Messages'=>'Pesan','Mail'=>'Surat','Form'=>'Formulir','Support'=>'Dukungan','https://contactform7.com/support/'=>'https://contactform7.com/support/','FAQ'=>'Tanya Jawab','https://contactform7.com/faq/'=>'https://contactform7.com/faq/','Docs'=>'Dokumentasi','https://contactform7.com/docs/'=>'https://contactform7.com/docs/','Delete'=>'Hapus','Duplicate'=>'Duplikat','Status'=>'Status','You can also use this old-style shortcode:'=>'Anda juga dapat menggunakan jenis shortcode lama berikut:','Copy this shortcode and paste it into your post, page, or text widget content:'=>'Salin shortcode ini dan tempelkan pada pos, laman, atau konten widget teks Anda:','Enter title here'=>'Masukkan judul di sini','Save'=>'Simpan','You are not allowed to edit this contact form.'=>'Anda tidak diizinkan untuk mengedit formulir kontak ini.','https://contactform7.com/save-submitted-messages-with-flamingo/'=>'https://contactform7.com/save-submitted-messages-with-flamingo/','Spam filtering with Akismet'=>'Penyaringan spam dengan Akismet','https://contactform7.com/spam-filtering-with-akismet/'=>'https://contactform7.com/spam-filtering-with-akismet/','Setting up mail'=>'Menyiapkan pesan','https://contactform7.com/setting-up-mail/'=>'https://contactform7.com/setting-up-mail/','Contact Form 7 needs your support.'=>'Contact Form 7 membutuhkan dukungan Anda.','Dismiss'=>'Abaikan','<strong>Contact Form 7 %1$s requires WordPress %2$s or higher.</strong> Please <a href="%3$s">update WordPress</a> first.'=>'<strong>Contact Form 7 %1$s membutuhkan WordPress %2$s atau lebih tinggi.</strong> Mohon <a href="%3$s">perbarui WordPress</a> terlebih dulu.','Settings'=>'Pengaturan','Contact form deleted.'=>'Formulir kontak dihapus.','Contact form saved.'=>'Formulir kontak disimpan.','Contact form created.'=>'Formulir kontak dibuat.','Search Contact Forms'=>'Cari Formulir Kontak','Error in deleting.'=>'Eror saat menghapus.','You are not allowed to delete this item.'=>'Anda tidak diizinkan menghapus item ini.','You are not allowed to edit this item.'=>'Anda tidak diizinkan mengubah item ini.','Integration'=>'Integrasi','Contact Forms'=>'Formulir Kontak','Edit Contact Form'=>'Edit Formulir Kontak','Contact'=>'Kontak','Contact Form 7'=>'Contact Form 7']];