<?php

return array(
	'dependencies' => array(
		'react-jsx-runtime',
		'wp-api-fetch',
		'wp-block-editor',
		'wp-blocks',
		'wp-components',
		'wp-element',
		'wp-i18n',
		'wp-url',
	),
	'version' => WPCF7_VERSION,
);
