<?php 
/*
* Display Theme menus
*/
?>

<div class="container">
  	<div class="menubar">
  		<div class="row m-0">
	    	<div class="menubox col-lg-11 col-md-10 col-6 align-self-center">
	      		<div class="innermenubox">	      			
			          	<div class="toggle-nav mobile-menu">
	            			<button onclick="construction_hub_open_nav()" class="responsivetoggle"><i class="fas fa-bars"></i><span class="screen-reader-text"><?php esc_html_e('Open Button','construction-hub'); ?></span></button>
	          			</div>
         	 		<div id="mySidenav" class="nav sidenav">
            			<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'construction-hub' ); ?>">
			              	<?php 
			                  	wp_nav_menu( array( 
				                    'theme_location' => 'primary-menu',
				                    'container_class' => 'main-menu clearfix' ,
				                    'menu_class' => 'clearfix',
				                    'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
				                    'fallback_cb' => 'wp_page_menu',
			                  	) );
			              	 ?>
              				<a href="javascript:void(0)" class="closebtn mobile-menu" onclick="construction_hub_close_nav()"><i class="fas fa-times"></i><span class="screen-reader-text"><?php esc_html_e('Close Button','construction-hub'); ?></span></a>
	            		</nav>
	          		</div>
          			<div class="clearfix"></div>
        		</div>
	    	</div>
	    	<div class="col-lg-1 col-md-2 col-5 align-self-center d-flex justify-content-center align-items-center">
	        	<span class="search-bar">
	            	<button type="button" class="open-search"><i class="fas fa-search"></i></button>
	        	</span>
	      	</div>
	      	<div class="search-outer">
	          	<div class="inner_searchbox w-100 h-100">
	              <?php get_search_form(); ?>
          		</div>
	          	<button type="button" class="search-close"><?php esc_html_e('CLOSE', 'construction-hub'); ?></button>
	      	</div>
      	</div>
  	</div>
</div>