<ul class="ct-parent">
	<li class="ct-item ct-footer">
		<ul class="clearfix">
			<li class="ct-feature"><strong><?php esc_html_e('Upgrade to Pro', 'mags'); ?></strong><p><?php esc_html_e('Unlock all the features with Mags Pro', 'mags'); ?></p></li>
			<li></li>
			<li class="ct-pro"><a target="_blank" href="<?php echo esc_url('https://www.themehorse.com/themes/mags-pro'); ?>"><?php esc_html_e('Upgrade to Pro', 'mags'); ?></a></li>
		</ul>
	</li>
	<li class="ct-item ct-header">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('LIST OF FEATURES', 'mags'); ?></li>
			<li class="ct-free"><?php esc_html_e('FREE', 'mags'); ?></li>
			<li class="ct-pro"><?php esc_html_e('PRO', 'mags'); ?></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('WooCommerce Compatible', 'mags'); ?></li>
			<li class="ct-free"><?php esc_html_e('Normal', 'mags'); ?></li>
			<li class="ct-pro"><?php esc_html_e('Advance', 'mags'); ?></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Header Style', 'mags'); ?></li>
			<li class="ct-free">2</li>
			<li class="ct-pro">3</li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Navigation Centered', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Social Proflies', 'mags'); ?></li>
			<li class="ct-free">4</li>
			<li class="ct-pro">25+</li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Banner Variations', 'mags'); ?></li>
			<li class="ct-free"><?php esc_html_e('1 Style', 'mags'); ?></li>
			<li class="ct-pro"><?php esc_html_e('5 Styles', 'mags'); ?></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Banner Image Slider', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Navigation Sticky', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Font Family', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><?php esc_html_e('700+ Google Fonts', 'mags'); ?></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Font Size', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Font Color', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Color Options', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Color Scheme', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Color Elements', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Category Color', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Excerpt Modification', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Posts Number for Sections', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Featured Posts Slider/Center/Full Width', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Background Parallax/Video', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Custom Widgets', 'mags'); ?></li>
			<li class="ct-free">4</li>
			<li class="ct-pro">7</li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Widget Advertisement', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Widget Posts Tab', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Widget Double Category Posts', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Widget Card/Block Posts', 'mags'); ?></li>
			<li class="ct-free"><?php esc_html_e('2 Column', 'mags'); ?></li>
			<li class="ct-pro"><?php esc_html_e('1/2/3 Column and Slider', 'mags'); ?></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Widget Multiple Layout Posts', 'mags'); ?></li>
			<li class="ct-free"><?php esc_html_e('2 Styles', 'mags'); ?></li>
			<li class="ct-pro"><?php esc_html_e('5 Styles', 'mags'); ?></li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Footer Widget Column', 'mags'); ?></li>
			<li class="ct-free">4</li>
			<li class="ct-pro">2/3/4</li>
		</ul>
	</li>
	<li class="ct-item">
		<ul class="clearfix">
			<li class="ct-feature"><?php esc_html_e('Footer Editor', 'mags'); ?></li>
			<li class="ct-free"><i class="dashicons dashicons-no-alt"></i></li>
			<li class="ct-pro"><i class="dashicons dashicons-yes"></i></li>
		</ul>
	</li>
	<li class="ct-item ct-footer">
		<ul class="clearfix">
			<li class="ct-feature"><strong><?php esc_html_e('Upgrade to Pro', 'mags'); ?></strong><p><?php esc_html_e('Unlock all the features with Mags Pro', 'mags'); ?></p></li>
			<li></li>
			<li class="ct-pro"><a target="_blank" href="<?php echo esc_url('https://www.themehorse.com/themes/mags-pro'); ?>"><?php esc_html_e('Upgrade to Pro', 'mags'); ?></a></li>
		</ul>
	</li>
</ul>