/*rtl css*/
:root {
    --color-primary1:#f68121;
    --font-awesome:'FontAwesome';
}
html {
  line-height: 1.15;
  -ms-text-size-adjust: 100%;
  -webkit-text-size-adjust: 100%;
}
body{
  margin:0;
  padding:0;
  -ms-word-wrap:break-word;
  word-wrap:break-word;
  background-color:#fff;
  font-size:15px;
  color: #676767;
  font-family: 'Fira Sans', sans-serif;
  overflow-x: hidden;
}
h1,h2,h3,h4,h5,h6{
  color: #252c3a;
  text-wrap:balance;
}
p{
  font-size: 15px;
  color: #797e86;
  letter-spacing: 1px;
  font-family: 'Poppins', sans-serif;
  text-wrap:balance;
}
a{
  text-decoration:none;
  color:var(--color-primary1);
}
a:hover{
  text-decoration:none;
  color:var(--color-primary1);
}
input[type="search"] {
  padding: 10px;
  border: 1px solid #ebebeb;
  font-size: 15px;
}
button[type="submit"] {
  padding: 11px;
  background: var(--color-primary1);
  border: none;
  cursor: pointer;
  color: #fff;
}
img {
  height: auto;
  max-width: 100%;
  vertical-align: middle;
}
textarea{
  width: 100%;
}
.box-content a,
#theme-sidebar .textwidget a,
#footer .textwidget a,
.comment-body a,
.entry-content a,
.entry-summary a{
  text-decoration: underline;
  color: var(--color-primary1);
}
/*--------------------------------------------------------------
Accessibility CSS
--------------------------------------------------------------*/

/* Text meant only for screen readers. */
.screen-reader-text {
  border: 0;
  clip: rect(1px, 1px, 1px, 1px);
  clip-path: inset(50%);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
  word-wrap: normal !important;
}
.screen-reader-text:focus {
  background-color: #eee;
  clip: auto !important;
  clip-path: none;
  color: #444;
  display: block;
  font-size: 1em;
  height: auto;
  right: 5px;
  line-height: normal;
  padding: 15px 23px 14px;
  text-decoration: none;
  top: 5px;
  width: auto;
  z-index: 100000; /* Above WP toolbar. */
}

/*--------------------------------------------------------------
Header
--------------------------------------------------------------*/
.headerbox {
  padding: 0 25px;
  background: #252c3a;
  position: relative;
  z-index: 99;
}
.page-template-front-page #header {
    position: relative;
    margin-top: -64px;
}
.contact-section {
  border-bottom: 1px solid #393f4c;
  padding: 10px 0 0;
}
.call, .email{
  padding-bottom: 10px;
}
.headerbox i{
  font-size: 32px;
  color: var(--color-primary1);
  padding: 0px 18px;
}
span.infotext {
  font-size: 13px;
  color: #b3b6b9;
}
span.simplep a{
  color: #d0d1d3;
  font-size: 16px;
}
.email {
  text-align: left;
}
.logo{
  position: absolute;
  z-index: 999;
  right: 0;
  left: 0;
  bottom: 0;
  top: auto;
  text-align: center;
  width: 80%;
  height: auto;
  padding: 20px 20px;
  background: var(--color-primary1);
  border-top-right-radius: 2px;
  border-top-left-radius: 2px;
  margin: 0 auto;
  display: flex;
  justify-content: center;
  align-items: center;
  padding: 1em;
  flex-direction: column;
}
.logo h1 a, .logo p a{
  color: #fff;
}
.logo h1 a, .logo p a{
  font-size: 30px;
  font-weight: bold;
}
.logo p {
  margin: 0;
  color: #fff;
}
/*Header Image */
body.home.page-template.page-template-page-template.page-template-custom-home-page.page-template-page-templatecustom-home-page-php.page.logged-in.admin-bar.woocommerce-js.has-header-image.customize-support .headerimg{
  display: none !important;
  height: auto !important;
}
.woocommerce-cart .headerimg{
  display: none;
}
.headerimg {
  display: block;
  height: 250px;
  background-size: cover;
  object-fit: cover;
}
div#header {
    position: relative;
    top: -50px;
    margin-bottom: -5em;
}
/*--------------------------------------------------------------
Menu bar
--------------------------------------------------------------*/
@keyframes smoothScroll {
  0% {
    transform: translateY(-40px);
  }
  100% {
    transform: translateY(0px);
  }
}
.scrolled {
  position: fixed;
  top: 0;
  width: 100%;
  z-index: 99;
  box-shadow: 0px 0px 20px 10px rgba(0,0,0,0.25);
  background: #252c3a;
}
.menubar {
  -webkit-transition: all 0.5s ease;
  -moz-transition: position 10s;
  -ms-transition: position 10s;
  -o-transition: position 10s;
  transition: all 0.5s ease;
  background: #252c3a;
}
ul.list_nav {
  margin: 0 auto;
  text-align: center;
  display: block;
}
.main-navigation li.page_item_has_children:after,
.main-navigation li.menu-item-has-children:after{
  content: '\f0d7';
  position: absolute;
  left: 20px;
  top: 19px;
  color: #8b8888;
  font-size: 13px;
  font-family: 'Font Awesome 5 Free';
  font-weight: 900;
}

.main-navigation ul ul.page_item_has_children:after{
color: #222222;
}
.main-navigation ul{
  list-style: none;
  margin: 0;
  padding-right: 0;
}
.main-navigation li{
  position: relative;
  padding: 17px 12px;
  display: inline-block;
}
.main-navigation a{
  display: block;
  color: #8b8888;
  padding: 1px 0 0 18px;
  font-size: 14px;
  font-weight: 500;
  position: relative;
  letter-spacing: 1px;
  border-left: 1px solid #525761;
}
.main-navigation a:hover{
  color: var(--color-primary1);
}
.main-navigation ul ul{
  opacity: 0;
  position: absolute;
  top: 100% ;
  background: #252c3a;
  min-width: 215px;
  z-index: 9999;
}
.main-navigation ul ul ul{
  right: 100%;
  top: 0;
}
.main-navigation ul ul a{
  color: #fff !important;
  border: none;
  padding: 10px
}
.main-navigation ul ul a:hover{
  background: var(--color-primary1);
}
.main-navigation ul ul li,
.menubar.scrolled .main-navigation ul ul li{
  float: none;
  display: block;
  text-align: right;
  border-bottom: 1px solid #cccccc;
  border-right: none;
  border-left: none !important;
  padding: 0;
}
.main-navigation ul ul li:last-child{
  border-bottom: 0;
}
.main-navigation ul li:hover > ul{
  opacity: 1;
}
.main-navigation li.menu-item-has-children:hover > ul, .main-navigation li.menu-item-has-children:focus > ul, .main-navigation li.menu-item-has-children.focus > ul{
  opacity: 1;
}
.main-navigation .current_page_item > a,
.main-navigation .current-menu-item > a,
.main-navigation .current_page_ancestor > a{
  color: var(--color-primary1);
}
.main-navigation .menu > ul > li.highlight{
  background-color: var(--color-primary1);
}
.main-navigation .menu > ul > li.highlight:hover{
  background: transparent;
}
.menubar.scrolled .menu > ul > li:hover > a:after,
.menubar.scrolled .menu > ul > li.current_page_item > a:after,
.menubar.scrolled .menu > ul > li.current-menu-item > a:after{
  height: 2px;
}
.menu > ul > li.exoplanet-search:after{
  background: transparent !important;
}
.main-navigation ul ul li:hover > a{
  color: #fff;
}
.toggle-nav, a.closebtn{
  display: none;
}
.main-navigation .sub-menu {
  list-style: none;
  padding-right: 0;
  opacity: 0;
  right: -9999px;
  z-index: 99999;
  width: 200px !important;
}
.main-navigation ul.children{
  opacity: 0;
}
.main-navigation ul li:not(.off-canvas):hover > ul.children,
.main-navigation ul li:not(.off-canvas)[focus-within] > ul.children,
.main-navigation ul li:not(.off-canvas):focus-within > ul.children  {
  opacity: 1;
}
.main-navigation .menu-item-has-children:not(.off-canvas):hover > .sub-menu,
.main-navigation .menu-item-has-children:not(.off-canvas):focus > .sub-menu,
.main-navigation .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu,
.main-navigation .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menum,
.main-navigation .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu  {
  display: block;
  right: 0;
  margin-top: 0;
  opacity: 1;
  width: auto;
  min-width: 100%;
}
ul.sub-menu ul.sub-menu{ 
  right: 202px !important
}
/*-----------------Search pop up----------------*/
.inner_searchbox{
  background: #fff;
  max-height: 150px;
  display: flex;
  justify-content: center;
  position: relative;
  box-shadow: 0px 0px 12px #c0bebe;
  transition: 1s height ease-in-out;
}
.search-close {
    position: absolute;
    top: 0;
    font-size: 24px;
    z-index: 9999;
    left: 2%;
    color: #332f2e;
    background: none;
    cursor: pointer;
    transition: 0.5s height ease-in-out;
}
.inner_searchbox form.search-form {
  width: calc(100% - 30px);
  color: #fff;
  border: none;
  border-bottom: 1px solid #eae6e6;
  position: absolute;
  bottom: 20px;
  display: flex;
  padding: 0;
  border-radius: 0;
  background: #ffffff;
  max-width: 1200px;
  text-align: right;
}
.inner_searchbox form.search-form label {
  width: 90%;
}
.inner_searchbox input.search-field {
  padding: 10px;
  font-size: 20px;
  font-weight: 500;
  color: #112b38;
  max-height: 1200px;
  border: 0;
  width: 100%;
}
.inner_searchbox input.search-submit {
  padding: 8px 35px;
  margin: 5px 0;
  font-size: 20px;
}
.search-bar button{
  background: transparent;
  border: 0;
}
.search-outer {
  position: fixed;
  top: 0;
  right: 0;
  width: 100%;
  padding: 0;
  visibility: hidden;
  text-align: center;
  height: 100%;
  transition: 1s height ease-in-out;
  z-index: 999999;
}
body.search-focus .search-outer{
  visibility: visible;
  transition: 1s height ease-in-out;
}
body.admin-bar .inner_searchbox{
  margin-top: 32px;
}
body.admin-bar .search-close{
  top:38px;
}
button.search-close:focus{
  outline:2px solid #000;
}
.search-outer button.search-submit {
 border: 0;
 background: transparent;
}
.search-outer .inner_searchbox button[type="submit"]{
    background:none;
}
.search-outer input.search-field {
 border: none;
 padding: 4px 0;
 background: transparent;
 width: 95%;
}
.search-bar i {
  font-size: 21px;
  background-color: var(--color-primary1);
  color: #fff;
  padding: 20px;
  border-radius: 0;
  display: inline-block;
  text-align: center;
}
.search-box i{
  color: #fff;
}
.search-bar button {
  background: none;
  border:none;
}
.search-outer .inner_searchbox button[type="submit"]{
  background-color: var(--color-primary1);
  color: #fff;
  padding: 12px 24px;
  text-align: center;
  letter-spacing: 2px;
  display: inline-block;
  font-weight: 600;
  text-transform: uppercase;
  font-size: 18px;
}
.inner_searchbox button[type="submit"]:hover{
  background-color: #000;
}
button.search-submit i{
    color: #332f2e;
}
.modal-content{
  background: transparent;
  border: 0;
}
.modal-dialog{
  pointer-events: all;
}
.modal-body{
  padding: 0;
}
#myModal, .modal-open {
  padding: 0 !important;
}
.modal-open{
  overflow-y: scroll;
}
body.admin-bar .inner_searchbox{
  margin-top: 32px;
}
body.admin-bar .closepop{
  top:30px;
}

/*--------------------------------------------------------------
Post Pages
--------------------------------------------------------------*/

.page-box {
  margin: 0 0px 4em 0;
  padding: 45px 30px;
  background: #fff;
  border-radius: 12px;
  box-shadow: 0 0 2px #aaa;
  border-bottom: 3px solid var(--color-primary1);
}
.page-box:hover{
  box-shadow: 0 0 20px #cfcfcf;
}
.box-image img,
.box-content img {
  width: 100%;
  height: auto;
}
.blog .box-image img{
  border-radius: 0;
}
#category-post .entry-video, #category-post .entry-audio{
  padding-bottom: 7px;
}
.woocommerce .single-page-img{
  display: none;
}
.woocommerce-MyAccount-content p a{
  text-decoration: underline;
}
.single-post .header-img, .page .header-img{
  display: none;
}
.external-div {
  position: relative;
  text-align: center;
  margin-top: 0;
  height: 350px;
  margin-bottom: 0;
  background: #000;
}
.external-div .box-image img,.header-img{
  object-fit: cover;
  /*position: absolute;*/
  height: 350px;
  width: 100%;
  right: 0;
  left: 0;
  background-size:cover;
}
.box-text{
  position: absolute;
  bottom: auto;
  top: 50%;
  transform: translateY(-50%);
  left: 30%;
  right: 30%;
  z-index: 9999;
  text-align: center;
}
.box-text h2{
    color: #fff;
    text-transform:uppercase;
    letter-spacing: 3px;
}
.box-info i {
  margin-left: 5px;
  color: var(--color-primary1);
  font-size: 16px;
}
.box-info {
  padding: 5px 0;
}
.content-area .box-content .box-info a {
  margin-left: 10px;
  font-size: 15px;
  color: #001837;
}
.page-box p {
  margin: 15px 0;
}
.page-box h4 a {
  font-size: 25px;
  font-weight: bold;
  letter-spacing: 1px;
  text-transform: uppercase;
  color: #121212;
}
.page-box h4 {
  border-bottom: 1px solid #ebebeb;
  padding-bottom: 10px;
  margin-bottom: 10px;
}
.page-box a,.nav-links a {
  text-decoration: none;
}
.readmore-btn a {
  background: var(--color-primary1);
  font-weight: 600;
  padding: 9px 15px;
  letter-spacing: 1px;
  font-size: 15px;
  color: #fff;
  display: inline-block;
  border-radius: 5px;
  margin-top: 10px;
}
.readmore-btn a:hover{
  background:#000;
}
/*block widget for footer*/
#footer .wp-block-details summary{
  color: #fff;
}
#footer .widget.widget_block.widget_text a{
  text-decoration: underline;
}
#footer .wp-calendar-table th{
  background-color: var(--color-primary1);
  color: #fff;
  border-color: var(--color-primary1);
}
#footer .tagcloud a, #footer p.wp-block-tag-cloud a{
  text-decoration: none;
}
/*block widget for sidebar*/
#secondary .wp-calendar-table th{
  background-color: var(--color-primary1);
  color: #fff;
  border-color: var(--color-primary1);
}
#secondary .widget.widget_block.widget_text p a{
  text-decoration: underline;
}
#secondary li a,#secondary .widget.widget_block.widget_tag_cloud a, #theme-sidebar li a{
  text-decoration: none;
}
/*--------------------------------------------------------------
SLIDER
--------------------------------------------------------------*/
#slider{
  max-width:100%;
  margin:auto;
  padding:0;
  background: #000;
}
#slider img {
  width: 100%;
  height: 700px;
  object-fit: cover;
  opacity: 0.5;
}
#slider .carousel-item-next,#slider .carousel-item-prev,#slider .carousel-item.active {
  display: block !important;
}
#slider .carousel-control-prev-icon, #slider .carousel-control-next-icon{
  background-image: none;
  font-size: 14px;
  font-weight: 800;
  letter-spacing: 1px;
  color: #fff;
  height: auto;
  width: auto;
  border: 2px solid;
  padding: 15px 18px;
}

#slider .carousel-control-prev-icon:hover, #slider .carousel-control-next-icon:hover{
  background-color:var(--color-primary1);
}
#slider .carousel-control-next, #slider .carousel-control-prev{
  opacity: 1;
  height: 50px;
  top: 50%;
}
.carousel-control-next-icon, .carousel-control-prev-icon{
  width: auto;
  height: auto;
}
#slider .carousel-caption {
  top: 45%;
  transform: translateY(-50%);
  bottom: auto;
}
#slider .inner_carousel h1 a {
  margin: 0;
  font-size: 40px;
  text-transform: uppercase;
  font-weight: 800;
  letter-spacing: 1px;
  color: #fff;
  padding-bottom: 0;
}
#slider .inner_carousel h1 a:hover, #our_project h3 a:hover,
span.simplep a:hover{
  color: var(--color-primary1);
}
#slider .inner_carousel p {
  font-size: 13px;
  letter-spacing: 0px;
   color: #fff;
}
.more-btn a {
  color: #fff;
  font-weight: 600;
  font-size: 15px;
  border:2px solid var(--color-primary1);
  padding: 12px 24px;
  border-radius: 4px;
  background:transparent;
}
.more-btn a:hover{
  background: #000;
  border:1px solid #000;
  color: #fff;
}
.more-btn{
  margin: 25px 0;
}
.remove-hd-bg .headerimg , .single-post .headerimg , .page-template-default .headerimg{
  display: none;
}
/*--------------------------------------------------------------
Our Project
--------------------------------------------------------------*/
#our_project {
  padding: 3% 0 0;
}
.project_bg{
  text-align: center;
}
.project_bg h2 {
  padding: 8px 0 0;
  color: #252c3a;
  font-size: 25px;
  letter-spacing: 1px;
  margin: 8px 0;
}
.project_bg p {
  color: #797e86;
  letter-spacing: 1px;
  font-weight: 500;
  font-size: 13px;
}
.project_bg{
  margin: 10px 0;
  padding: 10px 0;
  background: url(assets/images/scale.png) no-repeat;
  background-size: 100% 100%;
}
#our_project h3 a {
  font-size: 20px;
  text-transform: uppercase;
  letter-spacing: 0px;
  color: #fff;
  margin-bottom: 0;
  text-align: right;
}
.project_text {
  opacity: 0;
  padding: 0 25px;
  position: relative;
  top: -80px;
  right: 0em;
  left: 4em;
  bottom: 1em;
  -webkit-transition: 0.6s;
  transition: 0.6s;
}
.project_box:hover .project_text {
  opacity: 1;
}
#our_project .project-img img{
  opacity: 0.6;
  width: 100%;
  object-fit: cover;
  height: 250px;
}
#our_project .project-img{
  background-image: linear-gradient(to top, #252c3a 24%, transparent 63%);
}
#our_project i{
  background: var(--color-primary1);
  padding: 10px 12px;
  border-radius: 4px;
  color: #fff;
}

/*--------------------------------------------------------------
WOOCOMMERCE CSS
--------------------------------------------------------------*/
.woocommerce nav.woocommerce-pagination ul li {
  border-left: none;
}
.woocommerce nav.woocommerce-pagination ul li a,
.woocommerce nav.woocommerce-pagination ul li span{
  padding:15px;
}
.woocommerce nav.woocommerce-pagination ul li a:focus,
.woocommerce nav.woocommerce-pagination ul li a:hover,
.woocommerce nav.woocommerce-pagination ul li span.current{
  background: #252c3a;
  color: #fff;
}
.woocommerce nav.woocommerce-pagination ul{
  border:none;
}
.woocommerce form .form-row input.input-text,
.woocommerce form .form-row textarea{
  padding: 10px;
}
.woocommerce ul.products li.product .button,
a.checkout-button.button.alt.wc-forward {
  margin-top: 1em;
  font-size: 14px;
}
.woocommerce  .star-rating {
  margin: 0 auto 10px !important;
}
.woocommerce ul.products li.product .onsale,.woocommerce span.onsale{
  background: var(--color-primary1);
  padding: 0;
  top: 25px !important;
  left: 25px !important;
}
.woocommerce span.onsale{
  right: 25px;
  left: auto !important;
}
.products li {
  text-align: center;
  box-shadow: 0 0 10px 4px #ddd;
  padding: 15px !important;
  border-radius: 0px;
}
a.added_to_cart.wc-forward{
   padding: 15px;
   background: none;
   color: var(--color-primary1);
}
h2.woocommerce-loop-product__title,
.woocommerce div.product .product_title {
  color: #252c3a;
  margin-bottom: 10px !important;
}
.woocommerce ul.products li.product .price,
.woocommerce div.product p.price, .woocommerce div.product span.price {
  color: #252c3a;
  font-size: 15px
}
.woocommerce div.product .product_title,.woocommerce div.product p.price, .woocommerce div.product span.price{
  margin-bottom: 5px;
}
.wc-block-checkout__actions_row .wc-block-components-checkout-place-order-button,.wc-block-cart__submit-container a,.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button,.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt{
 background: var(--color-primary1);
  color: #fff;
  padding: 15px;
  border-radius: 0;
}
.woocommerce-cart table.cart td.actions .coupon .input-text{
  width: 50%;
}
.wc-block-cart__submit-container a:hover,.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover,.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover{
  background: #252c3a;
  color: #fff;
}
.woocommerce .quantity .qty {
  width: 5em;
  padding: 9px;
  border-radius: 0;
  border: solid 2px #252c3a;
  color: #252c3a
}
.col-1,.col-2 {
  max-width: 100%;
}
nav.woocommerce-MyAccount-navigation ul {
  list-style: none;
  padding: 0;
}
nav.woocommerce-MyAccount-navigation ul li {
   border: solid 2px #252c3a;
  padding: 10px;
  margin-bottom: 10px;
  box-shadow: -2px 2px 0 0 #252c3a;
  font-weight: bold;
}
nav.woocommerce-MyAccount-navigation ul li a{
  color: #252c3a !important;
  text-decoration: none;
}
span.woocommerce-input-wrapper,
.woocommerce label,span.password-input {
 width: 100%;
}
.woocommerce .woocommerce-ordering select {
  padding: 5px;
  font-size: 12px;
}
span.posted_in {
  display: block;
}
.woocommerce div.product div.images .woocommerce-product-gallery__image:nth-child(n+2) {
  width: 22%;
  display: inline-block;
  margin: 5px;
}
.wc-block-checkout__actions_row .wc-block-components-checkout-place-order-button{
  border: none !important;
}
.woocommerce #review_form #respond,.wc-block-checkout__form {
  padding: 20px;
  }
  .is-large.wc-block-cart .wc-block-cart-items td:after ,.is-large.wc-block-cart .wc-block-cart-items:after {
    border-color: transparent;
}
.wc-block-cart .wc-block-cart-items th,.wp-block-woocommerce-cart-order-summary-block .wc-block-cart__totals-title{
    padding: 10px !important;
}
.wc-block-cart table.wc-block-cart-items{
    margin: 0 !important;
}
.wc-block-checkout__form,.wc-block-cart-items__row,.wc-block-cart-items__header,.wp-block-woocommerce-checkout-order-summary-block,.wp-block-woocommerce-cart-order-summary-block,.is-large.wc-block-cart .wc-block-cart-items{
    border: 1px solid #ebebeb;
}
.wc-block-components-totals-wrapper:after,.wc-block-components-order-summary-item:after{
    border-color: #ebebeb;
    opacity: 1 !important;
}
.wc-block-cart__submit-container a{
    margin-top: 15px;
}
.wc-block-checkout__actions_row a{
    color: #252c3a;
}
.wc-block-components-notice-banner>.wc-block-components-notice-banner__content .wc-forward:hover{
  background: transparent;
  box-shadow: none;
}
.wc-block-components-notice-banner>.wc-block-components-notice-banner__content .wc-forward{  
  box-shadow: none;
}
.wc-block-components-product-badge {
    border: 1px dotted #4a5f6d !important;
    padding: 5px !important;
    background: #dce3e8;
    color: #4a5f6d;
}
.wp-block-woocommerce-checkout,.wp-block-woocommerce-cart{
  color: #252c3a;
}
.wp-block-woocommerce-cart.alignwide, .wp-block-woocommerce-checkout.alignwide.wc-block-checkout {
    margin-left: auto !important;
    margin-right: auto !important;
}
.wc-block-components-sidebar-layout .wc-block-components-main {
    padding-left: 0% !important;
}
/*--------------------------------------------------------------
Posts Numbers
--------------------------------------------------------------*/
.page-numbers {
  background: var(--color-primary1);
  color: #fff;
  padding: 7px;
  font-weight: bold;
}
.page-numbers:hover{
  background: #252c3a;
  color: #fff;
}
.prev.page-numbers,
.next.page-numbers {
  font-size: 15px;
  background: var(--color-primary1);
}
.prev.page-numbers:focus,
.prev.page-numbers:hover,
.next.page-numbers:focus,
.next.page-numbers:hover {
  background-color: #252c3a;
  color: #fff;
}
.page-links {
  font-size: 14px;
  font-weight: 800;
  padding: 2em 0 3em;
}
.page-links .page-number {
  color: #252c3a;
  display: inline-block;
  padding: 0.5em 1em;
}
.page-links a {
  display: inline-block;
}
.page-links a .page-number {
  color: #252c3a;
}
span.page-numbers.current {
  background: #252c3a;
}

a.page-numbers {
    color: white !important;
}
/* Post Navigation */
.post-navigation {
  font-weight: 500;
  margin: 3em 0;
}
.nav-subtitle {
  background: transparent;
  color: #252c3a;
  display: block;
  font-size: 11px;
  letter-spacing: 0.1818em;
  margin-bottom: 1em;
  text-transform: uppercase;
}
.nav-title {
  color: #333;
  font-size: 15px;
}
span.meta-nav {
  color: #fff;
  background: var(--color-primary1);
  padding: 5px;
}
.nav-previous {
  float: left;
}

/*--------------------------------------------------------------
 404 page
--------------------------------------------------------------*/

.error404 .page-content {
  padding-bottom: 4em;
}
.error404 .page-content .search-form,
.search .page-content .search-form {
  margin-bottom: 3em;
}
.error-404 input[type="search"] {
  border: solid 1px #252c3a;
  padding: 10px;
}
.error-404 [type="submit"] {
  padding: 10px;
  background: var(--color-primary1);
  border: solid 1px var(--color-primary1);
  cursor: pointer;
  font-weight: 500;
}

/*--------------------------------------------------------------
Sidebar
--------------------------------------------------------------*/

#theme-sidebar section {
  margin: 0 20px 2em 0;
  border-bottom: 3px solid var(--color-primary1);
  padding: 30px 35px;
  background: #fff;
  border-radius: 12px;
  box-shadow: 0 0 2px #aaa;
  border-bottom: 3px solid var(--color-primary1);
}
#theme-sidebar section:hover {
    box-shadow: 0 0 20px #cfcfcf;
}
#theme-sidebar ul li a{
  position: relative;
  z-index: 99;
}
#theme-sidebar ul li a::before {
    color: var(--color-primary1);
    content: "\f192";
    display: inline-block;
    font-family: FontAwesome;
    font-size: 12px;
    right: -25px;
    position: absolute;
    top: 0;
    margin-right: 2px;
}
#theme-sidebar a,#theme-sidebar .wp-block-latest-comments__comment-author, #theme-sidebar .wp-block-latest-comments__comment-link {
  color: #001837;
  font-size: 16px;
}
#theme-sidebar .wp-block-search .wp-block-search__label,#theme-sidebar h3, #theme-sidebar h1.wp-block-heading, #theme-sidebar h2.wp-block-heading, #theme-sidebar h3.wp-block-heading,#theme-sidebar h4.wp-block-heading, #theme-sidebar h5.wp-block-heading, #theme-sidebar h6.wp-block-heading {
  border-bottom: 1px solid #ebebeb;
  font-size: 23px;
  color: #121212;
  padding-bottom: 10px;
  letter-spacing: 1px;
  font-weight: bold;
  text-align: center;
  border-bottom: 2px solid #f1f1f1;
  position: relative;
  margin-bottom: 20px;
  padding-bottom: 20px;
  text-transform: uppercase;
}
#theme-sidebar .wp-block-search .wp-block-search__label:before,#theme-sidebar h3:before, #theme-sidebar h1.wp-block-heading:before, #theme-sidebar h2.wp-block-heading:before, #theme-sidebar h3.wp-block-heading:before,#theme-sidebar h4.wp-block-heading:before, #theme-sidebar h5.wp-block-heading:before, #theme-sidebar h6.wp-block-heading:before {
  position: absolute;
  content: "";
  right: 0;
  left: 0;
  margin: auto;
  background: var(--color-primary1);
  width: 77px;
  height: 3px;
  bottom: -3px;
  border-radius: 0;
}
#theme-sidebar ul,#footer ul {
  list-style: none;
  padding: 0;
}
#theme-sidebar li:last-child {
  border: none;
}
#theme-sidebar li {
  color: #001837;
  line-height: 20px;
  padding: 10px 5px;
  margin-right: 10px;
  font-size: 16px;
  margin-top: 10px;
}
#theme-sidebar ul li a{
  margin-bottom: 10px;
}
#theme-sidebar a:hover {
  color: var(--color-primary1);
}
#footer .wp-block-latest-comments article,
#theme-sidebar .wp-block-latest-comments article {
    margin-bottom: 0em;
}
#footer .wp-block-latest-comments__comment-meta,
#theme-sidebar .wp-block-latest-comments__comment-meta {
    margin-bottom: 0px;
}
#footer ol.wp-block-latest-comments,
#theme-sidebar ol.wp-block-latest-comments{
  padding-inline-start: 0px;
}
#theme-sidebar .textwidget img{
  width: 100%;
  height: auto;
}
#theme-sidebar select {
  padding: 10px;
  border: solid 1px #ebebeb;
  background: transparent;
  font-size: 14px;
  width: 100%;
  color: #001837;
}
#theme-sidebar .tagcloud a, #sidebar p.wp-block-tag-cloud a ,.post_tag a, #theme-sidebar .widget_tag_cloud a {
  border: 1px solid #cecece;
  color: #001837;
  line-height: 20px;
  padding: 7px 13px;
  font-size: 15px !important;
  display: inline-block;
  margin: 3px;
}
#theme-sidebar .tagcloud a:hover,#sidebar p.wp-block-tag-cloud a:hover, .post_tag a:hover,#theme-sidebar .widget_tag_cloud a:hover{
  background-color:var(--color-primary1);
  color: #fff;
  border-color: var(--color-primary1);
}

#theme-sidebar .tagcloud {
  margin-top: 15px;
}
#theme-sidebar input[type="search"],
#footer input[type="search"] {
  padding: 10px;
  width: 100%;
  border: 1px solid #ebebeb;
  font-size: 15px;
}
#footer .wp-block-search__inside-wrapper,
#theme-sidebar .wp-block-search__inside-wrapper{
  display: block;
}
#footer .wp-block-search__button,
#theme-sidebar .wp-block-search__button{
  margin-right: 0px;
}
#theme-sidebar button[type="submit"],
#footer button[type="submit"] {
  padding: 8px;
  width: 100%;
  margin-top: 10px;
  background: var(--color-primary1);
  border: none;
  cursor: pointer;
  color: #fff;
  font-size: 20px;
  font-family: 'Oswald', sans-serif;
}
#theme-sidebar table#wp-calendar {
  border: solid 1px #ebebeb;
  text-align: center;
  margin-top: 15px;
  width: 100%;
}
#footer.wp-block-calendar,
#theme-sidebar.wp-block-calendar{
  text-align: right;
}
#theme-sidebar th,#theme-sidebar td {
  border-left: solid 1px #ebebeb;
  padding: 10px 0;
}
#theme-sidebar tr {
  border-bottom: solid 1px #ebebeb;
}
.woocommerce #tp_content {
  margin-top: 30px;
}
#theme-sidebar .textwidget img {
  width: 100%;
  height: auto;
}
#theme-sidebar  .p {
  background: #fff;
  border: 1px solid #f0f0f0;
  max-width: 96%;
  padding: 5px 3px 10px;
}
#footer .wp-block-media-text__media img, #theme-sidebar .wp-block-media-text__media img{
padding-top: 15px;
}
#footer .wp-block-media-text,
#theme-sidebar .wp-block-media-text {
  box-sizing: border-box;
  direction: rtl;
  display: inline;
  grid-template-columns: 50% 1fr;
  grid-template-rows: auto;
}
/*--------------------------------------------------------------
Comments
--------------------------------------------------------------*/
#comments p a, .woocommerce-MyAccount-content p a, .content-area figure a, .content-area .right-sidebar p a, .content-area table a,
.content-area dd a, .box-content p a, .content-area li a, .wp-block-heading a{
  text-decoration: underline;
}
#comments #respond,.related-post-block{
  border: 1px solid #ebebeb;
  padding: 20px;
}
#comments {
  clear: both;
  padding: 2em 0 0.5em;
}
.comments-title {
  font-size: 20px;
  margin-bottom: 1.5em;
}
.comment-list,
.comment-list .children {
  list-style: none;
  margin: 0;
  padding: 0;
}
.comment-list li:before {
  display: none;
}
.comment-body {
  margin-right: 65px;
}
.comment-author {
  font-size: 16px;
  margin-bottom: 0.4em;
  position: relative;
  z-index: 2;
}
.comment-author .avatar {
  height: 50px;
  right: -65px;
  position: absolute;
  width: 50px;
}
.comment-author .says {
  display: none;
}
.comment-meta {
  margin-bottom: 1.5em;
}
.comment-metadata {
  color: #767676;
  font-size: 10px;
  font-weight: 800;
  letter-spacing: 0.1818em;
  text-transform: uppercase;
}
.comment-metadata a {
  color: #767676;
}
.comment-metadata a.comment-edit-link {
  color: #252c3a;
  margin-right: 1em;
}
.comment-body {
  color: #333;
  font-size: 14px;
  margin-bottom: 4em;
}
.comment-reply-link {
  font-weight: 800;
  position: relative;
}
.comment-reply-link .icon {
  color: #252c3a;
  right: -2em;
  height: 1em;
  position: absolute;
  top: 0;
  width: 1em;
}
.children .comment-author .avatar {
  height: 30px;
  right: -45px;
  width: 30px;
}
.bypostauthor > .comment-body > .comment-meta > .comment-author .avatar {
  border: 1px solid #333;
  padding: 2px;
}
.no-comments,
.comment-awaiting-moderation {
  color: #767676;
  font-size: 14px;
  font-style: italic;
}
.comments-pagination {
  margin: 2em 0 3em;
}
.comment-form #wp-comment-cookies-consent {
  margin: 0 0 0 10px;
}
.comment-form .comment-form-cookies-consent label {
  display: inline;
}
#comments input[type="submit"] {
  background: var(--color-primary1);
  border: none;
  padding: 10px 50px;
  font-weight: 500;
  letter-spacing: 1px;
  cursor: pointer;
  color: #fff;
}
input[type="text"],
input[type="email"],
input[type="phno"],
input[type="password"],
textarea,
input#url{
  border:1px solid #c8c8c8;
  width:100%;
  font-size:16px;
  padding:10px 10px;
  margin:0 0 23px 0;
  height:auto;
}

/*--------------------------------------------------------------
Commen CSS
--------------------------------------------------------------*/

#primary {
  padding: 3% 0;
}
.sticky .page-box h4{
  background: url(assets/images/pin.png) no-repeat scroll 100% 0px;
  padding-right: 40px;
}
#gallery-1 img {
  border: 2px solid #252c3a !important;
}
#gallery-1 .gallery-item {
  width: 30% !important;
  margin: 4px;
}
iframe,
.entry-audio audio{
  width: 100%;
}
.entry-video {
    width: 100%;
}
.entry-audio {
    width: 100%;
}

/*--------------------------------------------------------------
  Pre Loader
--------------------------------------------------------------*/

.loader{
  background: #fff;
  z-index: 99999;
  width: 100%;
  height: 100%;
  top: 0;
  right: 0;
  position: fixed;
}
.center{
  position: absolute;
  top: 50%;
  right: 50%;
  transform: translate(50%,-50%);
  border: 5px solid #222222;
  border-radius: 50%;
}
.center1{
  width: 200px;
  height: 200px;
  border-right-color: var(--color-primary1);
  border-top-color: var(--color-primary1);
  animation: animateCenter1 2s infinite linear;
}
.center2{
  width: 100px;
  height: 100px;
  border-right-color: var(--color-primary1);
  border-top-color: var(--color-primary1);
  animation: animateCenter2 2s infinite linear;
}
.ring{
  position: absolute;
  top: 0;
  right: 50%;
  transform-origin: bottom;
  transform: translateX(50%);
  width: 4px;
  height: 50%;
  background: transparent;
}
.center1 .ring{
  transform: translateX(50%) rotate(-45deg);
}
.center2 .ring{
  transform: translateX(50%) rotate(135deg);
}
.ring::before{
  content: '';
  position: absolute;
  top: 0;
  right: 50%;
  transform: translate(50%,-50%);
  width: 30px;
  height: 30px;
  border-radius: 50%;
}
.center1 .ring::before{
  background: var(--color-primary1);
}
.center2 .ring::before{
  background: var(--color-primary1);
}
@keyframes animateCenter1{
  0%{
    transform: translate(50%,-50%) rotate(0deg);
  }
  100%{
    transform: translate(50%,-50%) rotate(-360deg);
  }
}
@keyframes animateCenter2{
  0%{
    transform: translate(50%,-50%) rotate(0deg);
  }
  100%{
    transform: translate(50%,-50%) rotate(360deg);
  }
}

/*--------------------------------------------------------------
Footer
--------------------------------------------------------------*/
#footer {
  background: #252c3a;
  letter-spacing: 1px;
  clear: both;
}
#footer section{
  margin-bottom: 2em;
}
#footer h2,#footer h3,#footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading,#footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {
  font-size: 32px;
  padding: 10px 0;
  color: #fff;
  border-bottom: dashed 1px #fff;
  margin-bottom: 10px;
}
#footer li a:hover{
  color: var(--color-primary1);
}
#footer .wp-block-search .wp-block-search__label,#footer .wp-block-latest-comments__comment-date,#footer p,#footer li a,#footer .wp-block-latest-comments__comment-author, #footer .wp-block-latest-comments__comment-link {
  color: #fff;
}
#footer li {
  color: #fff;
  font-size: 15px;
  padding: 5px 0;
}
#footer table#wp-calendar {
  border: dashed 1px #fff;
  text-align: center;
  margin-top: 15px;
  width: 100%;
}
#footer th,#footer td {
  border-left: dashed 1px #fff;
  padding: 5px 0;
  color: #fff;
}
#footer tr {
  border-bottom: dashed 1px #fff;
  color: #fff;
}
#footer select {
  padding: 5px;
  width: 100%;
}
#footer .widget_rss img{
  width: auto;
}
#footer .widget_rss li{
  border-bottom: solid 2px #656363;
  margin-bottom: 10px;
  padding-bottom: 10px;
}
#footer .textwidget {
  color: #8b8888;
}
#footer .tagcloud a,#footer p.wp-block-tag-cloud a {
  border: 1px dashed #fff;
  color: #fff;
  line-height: 20px;
  padding: 5px 10px;
  font-size: 12px !important;
  display: inline-block;
  margin-bottom: 5px;
}
#footer .tagcloud a:hover,#footer p.wp-block-tag-cloud a:hover{
  border: 1px dashed var(--color-primary1);
  color: var(--color-primary1);
}
.site-info {
  background: var(--color-primary1);
  padding: 15px 0;
}
.site-info p,
.site-info a{
  margin-bottom: 0;
  text-align: center;
  font-size: 15px;
  color: #fff;
}
.site-info a:hover{
  color: #000;
}

/*--------------------------------------------------------------
Scroll Top
--------------------------------------------------------------*/

#return-to-top {
  position: fixed;
  bottom: 20px;
  left: 20px;
  background: rgba(0, 0, 0, 0.7);
  width: 50px;
  height: 50px;
  display: block;
  text-decoration: none;
  -webkit-border-radius: 35px;
  -moz-border-radius: 35px;
  border-radius: 35px;
  display: none;
  -webkit-transition: all 0.3s linear;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
#return-to-top i {
  color: #fff;
  margin: 0;
  position: relative;
  right: 50%;
  top: 50%;
  transform: translate(50%, -50%);
  font-size: 19px;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
#return-to-top:hover {
  background: rgba(0, 0, 0, 0.9);
}
#return-to-top:hover i {
  color: #fff;
  top: 5px;
}

/*--------------------------------------------------------------
WordPress Core
--------------------------------------------------------------*/
.alignwide {
  margin-right : -80px;
  margin-left : -20px;
}
.alignfull {
  margin-right: -48px;
  width: calc(100% + 64px) !important;
  max-width: 100vw;
}
.alignfull img {
  width: 100vw;
}
.alignnone {
  margin: 5px 0 20px 20px;
}
.aligncenter,
div.aligncenter {
  display: block;
  margin: 5px auto 5px auto;
}
.alignright {
  float:left;
  margin: 5px 20px 20px 0;
}
.alignleft {
  float: right;
  margin: 5px 0 20px 20px;
}
a img.alignright {
  float: left;
  margin: 5px 20px 20px 0;
}
a img.alignnone {
  margin: 5px 0 20px 20px;
}
a img.alignleft {
  float: right;
  margin: 5px 0 20px 20px;
}
a img.aligncenter {
  display: block;
  margin-right: auto;
  margin-left: auto;
}
.wp-caption {
  background: #fff;
  border: 1px solid #f0f0f0;
  max-width: 96%;
  padding: 5px 3px 10px;
  text-align: center;
}
.wp-caption.alignnone {
  margin: 5px 0 20px 20px;
}
.wp-caption.alignleft {
  margin: 5px 0 20px 20px;
}
.wp-caption.alignright {
  margin: 5px 20px 20px 0;
}
.wp-caption img {
  border: 0 none;
  height: auto;
  margin: 0;
  max-width: 98.5%;
  padding: 0;
  width: auto;
}
.wp-caption p.wp-caption-text {
  font-size: 11px;
  line-height: 17px;
  margin: 0;
  padding: 0 4px 5px;
}

/*--------------------------------------------------------------
Media Queries
--------------------------------------------------------------*/
@media screen and (min-width: 320px) and (max-width: 768px){
  .logo{
    width: 100%;
  }
  .logo h1 a, .logo p a{
    font-size: 22px;
  }
  .search-bar i{
    font-size: 15px;
    padding:12px;
  }
    .external-div .box-image img, .header-img, .external-div{
      height: 200px;
    }
  .nav-previous{
    padding: 15px;
    text-align: center;
    float: none;
  }
  .nav-next{
    text-align: center;
  }
  .nav ul li a{
    font-size: 15px;
  }
  .readmore-btn a{
    font-size: 10px;
  }
}
  
@media screen and (max-width: 1000px){
  .search-close{
    font-size: 18px;
  }
  .search-outer .inner_searchbox button[type="submit"]{
    font-size: 14px;
    padding: 10px 15px;
  }
  .search-outer input.search-field{
    font-size: 14px;
  }
  .box-text{
    top: 50%;
    right: 5%;
    left: 5%;
  }
  .menubar{
    background: #252c3a;
  }
  .search-box i{
    padding: 14px;
  }
  .headerbox i{
    padding: 10px;
  }
  .headerbox i:after{
    content: none;
  }
  .main-navigation ul ul{
    background: transparent !important;
  }
  .main-navigation ul ul li, .menubar.scrolled .main-navigation ul ul li{
    border-bottom: none;
  }
     .main-navigation .sub-menu {
    width: 100% !important;
  }
  .main-navigation .sub-menu li {
    opacity: 1 !important;
    display: block !important;
  }
  .main-navigation .sub-menu{
    opacity: 1;
  }
  .toggle-nav {
    display: none;
    cursor: pointer;
    z-index: 999999;
    text-align: right;
    margin-right: 24px;
  }
  .toggle-nav button {
    font-size: 22px;
    color: #fff;
    margin: 16px 13px;
    background: var(--color-primary1);
    border: none;
    padding: 10px 15px;
  }
  .sidenav {
    height: 100%;
    width: 100%;
    position: fixed;
    z-index: 9999999;
    top: 0;
    left: 0;
    visibility: hidden;
    background-color: #393f4c;
    transition: 0.5s width ease-in-out;
    padding-top: 60px;
    overflow-y: scroll;
  }
  .sidenav.open{
    visibility: visible;
  }
  .sidenav .closebtn {
    position: absolute;
    top: 0;
    left: 25px;
    font-size: 36px;
    display: block;
    color: #ffffff;
  }
  .sidenav #site-navigation {
    width: 100%;
  }
  .toggle-nav span{
    font-size:30px;
    cursor:pointer;
    text-align: left;
  }
  .toggle-nav{
    display: block;
  }
  .main-navigation .menu{
    float: none;
    text-align: center;
  }
  .main-navigation ul ul li,
  #masthead.scrolled .main-navigation ul ul li{
    display: block;
  }
  .main-navigation .menu > ul > li.highlight{
    background: transparent !important;
  }
  .menu > ul > li:hover:before,
  .menu > ul > li.current_page_item:before,
  .menu > ul > li.current-menu-item:before{
    display: none;
  }
  .toggle i.fa.fa-bars,.toggle i.fa.fa-times {
    float: left;
    color: black;
  }
  .menubar .nav ul{
    width:100%;
    margin-top:0;
  }
  .menubar .nav ul li,
  .menubar.scrolled .main-navigation li{
    display:block;
    text-align:right;
    float:none;
    width: 100%;
  }
  .nav ul li a{
    padding: 10px;
    display: block;
    color: #ffffff;
    font-size: 14px !important;
  }
  .nav ul li a:hover{
    color:#ff8a00;
  }
  .nav ul li ul,
  .nav ul li ul ul{
    opacity: 1;
  }
  .nav ul li ul li a:before{
    content:"\00BB \00a0";
  }
  .nav ul li ul li a{
  padding-right:20px !important;
  }
  .nav ul li ul li ul li a{
    padding-right:30px !important;
  }
  .main-navigation ul ul{
    position: static;
    width: 100%;
    box-shadow: none;
  }
  .main-navigation li{
    padding: 0;
  }
  .scrolled{
    position: static;
  }
  div#header{
    position: static;
    margin-bottom: 0;
  }
  #footer h3 {
    font-size: 18px !important;
    margin-top: 5px;
}
.nav-links {
    padding-bottom: 21px;
  }
  #category-post img{
    padding-bottom: 10px;
  }
  .main-navigation li.page_item_has_children:after,
  .main-navigation li.menu-item-has-children:after{
    display: none;
  }
  .main-navigation ul ul a,.main-navigation ul ul a:hover{
    background: transparent !important;

  }
}
@media screen and (max-width: 575px){
  .full .page-box{
    margin: 30px 10px;
  }
}
@media screen and (max-width: 560px){
  .top-header,
  .headerbox,
  .call,
  .email{
    text-align: center;
  }
  .headerbox i:after{
    content: none;
  }
  .search-box {
    text-align: left;
  }
  .search-box i{
    border: none;
  }
  .search_outer{
    top: auto;
    left: 0;
    right: 0;
  }
  #slider img{
    height: 350px;
  }
  #slider .inner_carousel p{
    display: none;
  }
  #slider .inner_carousel h1 a{
    font-size: 20px;
  }
  #slider .more-btn a{
    padding: 6px 10pxs;
  }
  #slider .carousel-caption {
    top: 60%;
  }
  #slider .carousel-control-prev-icon,
  #slider .carousel-control-next-icon{
    padding: 6px 10px;
  }
  .logo{
    position: static;
    width: auto;
    height: auto;
    margin: 0;
  }
  .woocommerce ul.products.columns-3 li.product,
  .woocommerce-page ul.products.columns-3 li.product{
    width: 100%;
  }
  .woocommerce .woocommerce-ordering,
  .woocommerce-page .woocommerce-ordering{
    float: none;
  }
  #footer h3,#footer p,#footer ul,#footer img,.content-area{
    text-align: center;
  }
  #gallery-1 .gallery-item{
    width: auto !important;
  }
  .box-content h4 {
    margin-top: 10px;
  }
  h1.page-title {
    font-size: 22px;
    text-align: center;
}
  .page-numbers{
    font-size: 10px;
  }
  a.next.page-numbers{
    font-size: 10px;
  }
  #slider .carousel-caption{
    text-align: center !important;
    right: 15% !important;
    left: 15% !important;
  }

}
@media screen and (min-width: 1000px) and (max-width: 1024px){
  #slider .carousel-caption{
    top: 35%;
  }
}
@media screen and (min-width: 320px) and (max-width: 767px){
  .logo{
    position: static;
    width: auto;
    height: auto;
    padding: 12px;
    margin: 0;
  }
  .call,.email{
    text-align: center;
  }
  .search_inner input.search-field{
    width: 80%;
  }
}
@media screen and (max-width: 1200px){
    .wc-block-components-totals-wrapper,.is-medium table.wc-block-cart-items .wc-block-cart-items__row, .is-mobile table.wc-block-cart-items .wc-block-cart-items__row, .is-small table.wc-block-cart-items .wc-block-cart-items__row {
        padding: 16px 10px !important;
    }
    .wc-block-cart table.wc-block-cart-items{
        margin: 0 0 2em !important  ;
    }
}

@media screen and (min-width:1700px) and (max-width:1900px){
  .container{
    max-width: 1520px;
  }
}
@media screen and (min-width:1920px) {
  .container{
    max-width: 1620px;
  }
}
