body {
	text-align: right;
	direction: rtl;
	unicode-bidi: embed;
}
ul,
ol {
	padding-left: 0;
	padding-right: 20px;
}
blockquote {
	padding-left: 0;
	padding-right: 35px;
}
blockquote:before {
	left: auto;
	right: 0;
}
.wp-custom-header .wp-custom-header-video-button {
	right: auto;
	left: 20px;
}
.back-to-top {
	right: auto;
	left: 30px;
}
.info-bar ul {
	padding-right: 0;
}
.info-bar ul li {
	float: right;
	padding-right: 0;
	padding-left: 10px;
}
.info-bar ul li:last-child {
	padding-left: 0;
}
.info-bar .infobar-links li + li:before {
	margin-right: 0;
	margin-left: 10px;
}
.social-profiles ul {
	padding-right: 0;
}
.social-profiles ul li {
	float: right;
}
.navbar-head.header-overlay-dark:before {
	background-image: linear-gradient(to left, rgba(0, 0, 0, 0.8), rgba(0, 0, 0, 0.2));
}
.navbar-head.header-overlay-light:before {
	background-image: linear-gradient(to left, rgba(255, 255, 255, 0.8), rgba(255, 255, 255, 0.2));
}
.navbar-brand.brand-inline .custom-logo-link {
	margin-right: 0;
	margin-left: 10px;
}
.navbar-brand.brand-inline .custom-logo-link + .site-title-wrap {
	text-align: right;
}
.navbar-ad-section {
	text-align: left;
}
@media (min-width: 992px) {
	.navbar-brand-wrap {
		padding-right: 0;
		padding-left: 15px;
	}
}
.navbar-main {
	padding-right: 0;
	padding-left: 45px;
}
.navbar .main-navigation ul {
	padding-right: 0;
}
.main-navigation .dropdown-parent .dropdown-toggle {
	right: auto;
	left: 0;
}
.main-navigation .dropdown-parent .dropdown-toggle .dropdown-icon:after {
	content: "\f104";
}
.main-navigation .dropdown-parent .dropdown-toggle.toggle-on .dropdown-icon {
	transform: rotate(-90deg);
	-webkit-transform: rotate(-90deg);
	-moz-transform: rotate(-90deg);
}
.main-navigation ul li.menu-item-has-children > a,
.main-navigation ul li.page_item_has_children > a {
	padding-right: 15px;
	padding-left: 30px;
}
.main-navigation ul li ul li.menu-item-has-children > a,
.main-navigation ul li ul li.page_item_has_children > a {
	padding-right: 12px;
	padding-left: 18px
}
.main-navigation ul li.menu-item-has-children > a:after,
.main-navigation ul li.page_item_has_children > a:after {
	right: auto;
	left: 15px;
}
.main-navigation li ul li.menu-item-has-children > a:after,
.main-navigation li ul li.page_item_has_children > a:after {
	right: auto;
	left: 7px;
	content: '\f104';
}
.main-navigation .dropdown-menu,
.main-navigation li ul {
	left: auto;
	right: 0;
}
.main-navigation ul li ul li ul,
.headernav .main-navigation ul li ul li ul {
	left: auto;
	right: 198px;
}
.navbar .search-toggle {
	right: auto;
	left: 0;
}
.search-form .form-control {
	border-right-width: 1px;
	border-left-width: 0;
}
.search-block {
	right: auto;
	left: 0;
}
.no-js .owl-carousel,
.owl-carousel.owl-loaded,
.no-js .slick-slider,
.slick-slider {
	direction: ltr;
}
.post.sticky .entry-header .entry-title,
.hentry.sticky .entry-header .entry-title {
	padding-right: 0;
	padding-left: 35px;
}
.post.sticky .entry-header:before,
.hentry.sticky .entry-header:before {
	left: 0;
	right: auto;
}
.single-post .post.sticky .entry-header .entry-title,
body.single .hentry.sticky .entry-header .entry-title {
	padding-left: 0;
}
.single-post .post.sticky .entry-header .entry-meta.category-meta,
body.single .hentry.sticky .entry-header .entry-meta.category-meta {
	padding-right: 0;
	padding-left: 35px;
}
.entry-meta .cat-links a {
	margin-right: 0;
	margin-left: 7px;
	float: right;
}
.post-img-wrap .entry-meta .cat-links a,
.post-img-wrap + .entry-header .entry-meta .cat-links a {
	margin-left: 5px;
	margin-right: 0;
}
.post-img-wrap .entry-meta .cat-links a,
.post-img-wrap + .entry-header .entry-meta .cat-links a {
	margin-left: 5px;
	margin-right: 0;
}
.navigation.post-navigation .nav-links .nav-previous {
	float: right;
}
.navigation.post-navigation .nav-links .nav-next {
	float: left;
	text-align: left;
}
.navigation.post-navigation .nav-links .nav-previous a {
	padding-left: 30px;
	padding-right: 50px;
}
.navigation.post-navigation .nav-links .nav-next a {
	padding-left: 50px;
	padding-right: 30px;
}
.navigation.post-navigation .nav-links .nav-previous a:after {
	content: "\f105";
	right: 20px;
	left: 0;
}
.navigation.post-navigation .nav-links .nav-next a:after {
	content: "\f104";
	left: 20px;
	right: 0;
}
.comment-body {
	padding-left: 0;
	padding-right: 60px;
}
.children .comment-body {
	padding-left: 0;
	padding-right: 50px;
}
.comment-author .avatar {
	left: auto;
	right: 0;
}
#comments .children {
	padding-left: 0;
	padding-right: 30px;
}
#wp-comment-cookies-consent {
	margin-right: 0;
	margin-left: 10px;
}
.widget_display_replies ul.bbp-replies-widget .bbp-author-avatar,
.widget_display_topics ul.bbp-topics-widget .bbp-author-avatar {
	margin-right: 0;
	margin-left: 5px;
}
.widget_display_stats dd {
	margin-right: 0;
}

/* # Gutenberg Support */
.wp-block-quote,
.wp-block-quote.is-large,
.wp-block-quote.is-style-large {
	padding-left: 0;
	padding-right: 35px;
}
.wp-block-pullquote blockquote:before {
	margin-right: 0;
	margin-left: 10px;
	right: auto;
}

.post-boxed.inlined .post-img-wrap {
	float: right;
	margin-left: 15px;
	margin-right: 0;
}
.post-slider .owl-nav button.owl-next:before, 
.post-slider .slick-next:before {
	content: '\f104';
}
.post-slider .owl-nav button.owl-prev:before, 
.post-slider .slick-prev:before {
	content: '\f105';
}
.post-slider .owl-nav button.owl-prev,
.post-slider .slick-prev {
	left: auto;
	right: -17px;
}
.post-slider .owl-nav button.owl-next,
.post-slider .slick-next {
	right: auto;
	left: -17px;
}
.featured-slider.post-slider .owl-nav button.owl-prev,
.featured-slider.post-slider .slick-prev {
	left: auto;
	right: 20px;
}
.featured-slider.post-slider .owl-nav button.owl-next,
.featured-slider.post-slider .slick-next {
	right: auto;
	left: 20px;
}
.widget ol,
.widget ul {
	padding-right: 0;
}
.widget ol ol,
.widget ul ul {
	padding-left: 0;
	padding-right: 20px;
}
.widget_tag_cloud a {
	margin-right: 0;
	margin-left: 5px;
}
.widget_categories ul li a {
	display: inline-block;
}
.mags-widget-horizontal-vertical-posts .post-boxed.main-post.inlined .post-img-wrap{
	margin-left: 0;
}
.widget-area .mags-widget-recent-posts .post-boxed.inlined .post-img-wrap {
	margin-right: 0;
	margin-left: 10px;
}
.site-footer .widget-area .newscard-widget-recent-posts .post-boxed .post-img-wrap {
	margin-right: 0;
	margin-left: 10px;
}
.site-footer .widget-title {
	text-align: right;
}
.site-info .copyright .theme-link,
.site-info .copyright .privacy-link,
.site-info .copyright .author-link,
.site-info .copyright .wp-link,
.site-info .copyright .custom-content {
	padding-right: 0;
	padding-left: 8px;
}
.site-info .copyright .theme-link:after,
.site-info .copyright .privacy-link:after,
.site-info .copyright .author-link:after,
.site-info .copyright .wp-link:after {
	margin-left: 0;
	margin-right: 8px;
}
.site-info .social-profiles, .site-info .copyright {
	text-align: right !important;
}

@media (max-width: 991px) {
	.info-bar .infobar-links .infobar-links-menu-toggle,
	.info-bar .social-profiles .infobar-social-profiles-toggle {
		right: auto;
		left: 15px;
	}
	.info-bar .infobar-links.toggled-link-on ul {
		right: auto;
		left: 15px;
	}
	.info-bar .infobar-links ul li a {
		text-align: left;
	}
	.info-bar.infobar-links-on .container {
		padding-right: 15px;
		padding-left: 58px;
	}
	.info-bar.infobar-links-on .infobar-links {
		margin-right: 5px;
		margin-left: -43px;
	}
	.navbar-ad-section {
		text-align: right;
	}
	.navbar-brand-wrap {
		padding-right: 15px;
	}
	.navbar-main {
		padding-left: 0;
	}
	.search-block {
		left: auto;
	}
	.main-navigation .dropdown-parent.menu-item-has-children > a,
	.main-navigation .dropdown-parent.page_item_has_children > a {
		padding-right: 0;
		padding-left: 50px;
	}
	.main-navigation ul li.menu-item-has-children > a,
	.main-navigation ul li ul li.menu-item-has-children > a,
	.main-navigation ul li.page_item_has_children > a,
	.main-navigation ul li ul li.page_item_has_children > a {
		padding-right: 0;
		padding-left: 20px;
	}
	.main-navigation ul li.menu-item-has-children > a:after,
	.main-navigation li ul li.menu-item-has-children > a:after,
	.main-navigation ul li.page_item_has_children > a:after,
	.main-navigation li ul li.page_item_has_children > a:after {
		right: auto;
		left: 5px;
		content: "\f107";
	}
	.main-navigation li ul,
	.main-navigation ul li ul li ul,
	.headernav .main-navigation ul li ul li ul {
		right: auto;
	}
	.main-navigation ul li a,
	.main-navigation ul li ul li a,
	.main-navigation ul li ul li ul li a,
	.main-navigation ul li ul li ul li ul li a,
	.main-navigation ul li ul li ul li ul li ul li a {
		padding-right: 0;
		padding-left: 15px;
	}
	.main-navigation ul li ul li a,
	.main-navigation ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 30px;
	}
	.main-navigation ul li ul li ul li a,
	.main-navigation ul li ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 60px;
	}
	.main-navigation ul li ul li ul li ul li a,
	.main-navigation ul li ul li ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 90px;
	}
	.main-navigation ul li ul li ul li ul li ul li a,
	.main-navigation ul li ul li ul li ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li ul li ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 120px;
	}
	.site-info .social-profiles, .site-info .copyright {
		text-align: center !important;
	}
	.back-to-top {
		left: 15px;
	}
}

@media (max-width: 767px) {
	.info-bar.infobar-links-on .container {
		padding-right: 20px;
		padding-left: 63px;
	}
	.info-bar.infobar-links-on .infobar-links {
		margin-right: 0;
		margin-left: -63px;
	}
	.info-bar .infobar-links .infobar-links-menu-toggle,
	.info-bar .infobar-links.toggled-link-on ul {
		left: 20px;
	}
	.navbar-brand-wrap {
		padding-left: 20px;
		padding-right: 20px;
	}
	.main-navigation ul li ul li a,
	.main-navigation ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 20px;
	}
	.main-navigation ul li ul li ul li a,
	.main-navigation ul li ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 40px;
	}
	.main-navigation ul li ul li ul li ul li a,
	.main-navigation ul li ul li ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 60px;
	}
	.main-navigation ul li ul li ul li ul li ul li a,
	.main-navigation ul li ul li ul li ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li ul li ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 80px;
	}
	.back-to-top {
		left: 20px;
	}
}

@media (max-width: 575px) {
	.info-bar .infobar-links .infobar-links-menu-toggle {
		left: 15px;
	}
	.info-bar .container,
	.info-bar.infobar-links-on .container {
		padding-left: 100px;
		padding-right: 15px;
	}
	.info-bar.infobar-links-on .infobar-links {
		margin-left: -85px;
	}
	.info-bar .infobar-links.toggled-link-on ul {
		left: auto;
	}
	.info-bar.infobar-links-on .social-profiles .infobar-social-profiles-toggle {
		right: auto;
		left: 58px;
	}
	.info-bar .social-profiles {
		margin-right: -10px;
		margin-left: -105px;
		text-align: left;
	}
	.navbar-brand-wrap {
		padding-left: 15px;
		padding-right: 15px;
	}
	.main-navigation ul li ul li a,
	.main-navigation ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 15px;
	}
	.main-navigation ul li ul li ul li a,
	.main-navigation ul li ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 30px;
	}
	.main-navigation ul li ul li ul li ul li a,
	.main-navigation ul li ul li ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 45px;
	}
	.main-navigation ul li ul li ul li ul li ul li a,
	.main-navigation ul li ul li ul li ul li ul li.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li ul li.page_item_has_children > a,
	.main-navigation ul li ul li ul li ul li ul li.dropdown-parent.menu-item-has-children > a,
	.main-navigation ul li ul li ul li ul li ul li.dropdown-parent.page_item_has_children > a {
		padding-right: 60px;
	}
	.navigation.post-navigation .nav-links .nav-next a {
		padding-right: 15px;
		padding-left: 35px;
	}
	.navigation.post-navigation .nav-links .nav-previous a {
		padding-left: 15px;
		padding-right: 35px;
	}
	.navigation.post-navigation .nav-links .nav-next a:after {
		left: 15px;
	}
	.navigation.post-navigation .nav-links .nav-previous a:after {
		right: 15px;
	}
	.featured-slider.post-slider .owl-nav button.owl-prev,
	.featured-slider.post-slider .slick-prev {
		left: auto;
		right: 15px;
	}
	.featured-slider.post-slider .owl-nav button.owl-next,
	.featured-slider.post-slider .slick-next {
		right: auto;
		left: 15px;
	}
	.back-to-top {
		left: 15px;
	}

}
