<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-05-24 07:04:35+0000','plural-forms'=>'nplurals=2; plural=n > 1;','project-id-version'=>'Plugins - Hello Dolly - Stable (latest release)','language'=>'fr','messages'=>['Matt Mullenweg'=>'Matt Mullenweg','This is not just a plugin, it symbolizes the hope and enthusiasm of an entire generation summed up in two words sung most famously by Louis Armstrong: Hello, Dolly. When activated you will randomly see a lyric from <cite>Hello, Dolly</cite> in the upper right of your admin screen on every page.'=>'Ce n’est pas qu’une extension, cela symbolise l’espoir et l’enthousiasme d’une génération toute entière résumée en deux mots qui furent chantés par le fameux Louis Armstrong : Hello, Dolly. Lorsque vous l’activerez, vous verrez des paroles aléatoires de <cite>Hello, Dolly</cite> en haut à droite de votre écran d’administration sur chaque page.','Hello Dolly'=>'Hello Dolly','https://ma.tt/'=>'https://ma.tt/','https://wordpress.org/plugins/hello-dolly/'=>'https://fr.wordpress.org/plugins/hello-dolly/']];