<?php
/**
 * Displays footer widgets if assigned
 *
 * @package Construction Hub
 * @subpackage construction_hub
 */
?>
<?php

// Determine the number of columns dynamically for the footer (you can replace this with your logic).
$construction_hub_no_of_footer_col = get_theme_mod('construction_hub_footer_columns', 4); // Change this value as needed.

// Calculate the Bootstrap class for large screens (col-lg-X) for footer.
$construction_hub_col_lg_footer_class = 'col-lg-' . (12 / $construction_hub_no_of_footer_col);

// Calculate the Bootstrap class for medium screens (col-md-X) for footer.
$construction_hub_col_md_footer_class = 'col-md-' . (12 / $construction_hub_no_of_footer_col);
?>
<div class="container">
    <aside class="widget-area row py-2 pt-3" role="complementary" aria-label="<?php esc_attr_e( 'Footer', 'construction-hub' ); ?>">
        <?php
        $construction_hub_default_widgets = array(
            1 => 'search',
            2 => 'archives',
            3 => 'meta',
            4 => 'categories'
        );

        for ($construction_hub_i = 1; $construction_hub_i <= $construction_hub_no_of_footer_col; $construction_hub_i++) :
            $construction_hub_lg_class = esc_attr($construction_hub_col_lg_footer_class);
            $construction_hub_md_class = esc_attr($construction_hub_col_md_footer_class);
            echo '<div class="col-12 ' . $construction_hub_lg_class . ' ' . $construction_hub_md_class . '">';

            if (is_active_sidebar('footer-' . $construction_hub_i)) {
                dynamic_sidebar('footer-' . $construction_hub_i);
            } else {
                // Display default widget content if not active.
                switch ($construction_hub_default_widgets[$construction_hub_i] ?? '') {
                    case 'search':
                        ?>
                        <aside class="widget" role="complementary" aria-label="<?php esc_attr_e('Search', 'construction-hub'); ?>">
                            <h3 class="widget-title"><?php esc_html_e('Search', 'construction-hub'); ?></h3>
                            <?php get_search_form(); ?>
                        </aside>
                        <?php
                        break;

                    case 'archives':
                        ?>
                        <aside class="widget" role="complementary" aria-label="<?php esc_attr_e('Archives', 'construction-hub'); ?>">
                            <h3 class="widget-title"><?php esc_html_e('Archives', 'construction-hub'); ?></h3>
                            <ul><?php wp_get_archives(['type' => 'monthly']); ?></ul>
                        </aside>
                        <?php
                        break;

                    case 'meta':
                        ?>
                        <aside class="widget" role="complementary" aria-label="<?php esc_attr_e('Meta', 'construction-hub'); ?>">
                            <h3 class="widget-title"><?php esc_html_e('Meta', 'construction-hub'); ?></h3>
                            <ul>
                                <?php wp_register(); ?>
                                <li><?php wp_loginout(); ?></li>
                                <?php wp_meta(); ?>
                            </ul>
                        </aside>
                        <?php
                        break;

                    case 'categories':
                        ?>
                        <aside class="widget" role="complementary" aria-label="<?php esc_attr_e('Categories', 'construction-hub'); ?>">
                            <h3 class="widget-title"><?php esc_html_e('Categories', 'construction-hub'); ?></h3>
                            <ul><?php wp_list_categories(['title_li' => '']); ?></ul>
                        </aside>
                        <?php
                        break;
                }
            }

            echo '</div>';
        endfor;
        ?>
    </aside>
</div>