<div class="footer__nav">
    <ul>
        <li><a href="<?php echo esc_url('https://wpdeveloper.com/about/'); ?>" target="_blank" rel="nofollow"><?php esc_html_e('About Us', 'disable-comments'); ?></a></li>
        <li><a href="<?php echo esc_url('https://wpdeveloper.com/plugins/'); ?>" target="_blank" rel="nofollow"><?php esc_html_e('All Plugins', 'disable-comments'); ?></a></li>
        <li><a href="<?php echo esc_url('https://wpdeveloper.com/support/'); ?>" target="_blank" rel="nofollow"><?php esc_html_e('Support Forum', 'disable-comments'); ?></a></li>
        <li><a href="<?php echo esc_url('https://wpdeveloper.com/docs/'); ?>" target="_blank" rel="nofollow"><?php esc_html_e('Docs', 'disable-comments'); ?></a></li>
        <li><a href="<?php echo esc_url('https://wpdeveloper.com/terms-and-conditions/'); ?>" target="_blank" rel="nofollow"><?php esc_html_e('Terms Of Service', 'disable-comments'); ?></a></li>
        <li><a href="<?php echo esc_url('https://wpdeveloper.com/privacy-policy/'); ?>" target="_blank" rel="nofollow"><?php esc_html_e('Privacy', 'disable-comments'); ?></a></li>
    </ul>
</div>