<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2026-03-17 21:06:31+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Hello Dolly - Stable (latest release)','language'=>'de','messages'=>['https://ma.tt/'=>'https://ma.tt/','Matt Mullenweg'=>'Matt Mullenweg','This is not just a plugin, it symbolizes the hope and enthusiasm of an entire generation summed up in two words sung most famously by Louis Armstrong: Hello, Dolly. When activated you will randomly see a lyric from <cite>Hello, Dolly</cite> in the upper right of your admin screen on every page.'=>'Dies ist nicht nur ein Plugin, es symbolisiert in zwei Worten, gesungen von Louis Armstrong, die Hoffnung und den Enthusiasmus einer ganzen Generation: Hello, Dolly. Nach Aktivierung werden nach dem Zufallsprinzip aus dem Liedtext von <cite>Hello, Dolly</cite> Zeilen oben rechts im Administrationsbereich angezeigt.','https://wordpress.org/plugins/hello-dolly/'=>'https://de.wordpress.org/plugins/hello-dolly/','Hello Dolly'=>'Hello Dolly']];